summaryrefslogtreecommitdiffstats
path: root/src
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:39:40 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:39:40 -0600
commit1fc61c6e1d0a2b34f7b1d0de181bb4e6f954a8c2 (patch)
treefdf34e0c9a4211231bb084fb40d30d2dff677dea /src
parentabb8cd68f820cfe0c96965136890a6bdd1093db5 (diff)
downloadktechlab-1fc61c6e1d0a2b34f7b1d0de181bb4e6f954a8c2.tar.gz
ktechlab-1fc61c6e1d0a2b34f7b1d0de181bb4e6f954a8c2.zip
Remove additional unneeded tq method conversions
Diffstat (limited to 'src')
-rw-r--r--src/cnitem.cpp4
-rw-r--r--src/cnitem.h2
-rw-r--r--src/cnitemgroup.h4
-rw-r--r--src/docmanager.cpp18
-rw-r--r--src/document.cpp4
-rw-r--r--src/electronics/component.cpp2
-rw-r--r--src/electronics/component.h4
-rw-r--r--src/electronics/components/bussplitter.cpp2
-rw-r--r--src/electronics/components/eckeypad.cpp4
-rw-r--r--src/electronics/components/magnitudecomparator.cpp4
-rw-r--r--src/electronics/components/matrixdisplay.cpp4
-rw-r--r--src/electronics/components/parallelportcomponent.cpp6
-rw-r--r--src/electronics/components/piccomponent.cpp4
-rw-r--r--src/electronics/components/ram.cpp18
-rw-r--r--src/electronics/components/rotoswitch.cpp4
-rw-r--r--src/electronics/components/serialportcomponent.cpp2
-rw-r--r--src/electronics/gpsimprocessor.cpp14
-rw-r--r--src/electronics/port.cpp12
-rw-r--r--src/flowcontainer.cpp6
-rw-r--r--src/flowparts/callsub.cpp2
-rw-r--r--src/flowparts/count.cpp2
-rw-r--r--src/flowparts/delay.cpp2
-rw-r--r--src/flowparts/embed.cpp2
-rw-r--r--src/flowparts/flowpart.cpp4
-rw-r--r--src/flowparts/flowpart.h6
-rw-r--r--src/flowparts/inputbutton.cpp2
-rw-r--r--src/flowparts/interrupt.cpp2
-rw-r--r--src/flowparts/keypad.cpp4
-rw-r--r--src/flowparts/pinmapping.cpp12
-rw-r--r--src/flowparts/pulse.cpp2
-rw-r--r--src/flowparts/readport.cpp2
-rw-r--r--src/flowparts/repeat.cpp2
-rw-r--r--src/flowparts/setpin.cpp2
-rw-r--r--src/flowparts/sevenseg.cpp4
-rw-r--r--src/flowparts/while.cpp2
-rw-r--r--src/flowparts/writeport.cpp2
-rw-r--r--src/gui/generaloptionswidget.ui2
-rw-r--r--src/gui/itemselector.cpp4
-rw-r--r--src/gui/logicwidget.ui2
-rw-r--r--src/gui/logview.cpp10
-rw-r--r--src/gui/microsettingsdlg.cpp6
-rw-r--r--src/gui/newfilewidget.ui2
-rw-r--r--src/gui/oscilloscopeview.cpp4
-rw-r--r--src/gui/oscilloscopeview.h2
-rw-r--r--src/gui/oscilloscopewidget.ui4
-rw-r--r--src/gui/probepositioner.cpp2
-rw-r--r--src/gui/propertieslistview.cpp2
-rw-r--r--src/gui/settingsdlg.cpp16
-rw-r--r--src/item.cpp28
-rw-r--r--src/item.h18
-rw-r--r--src/itemdocument.cpp14
-rw-r--r--src/itemdocumentdata.cpp8
-rw-r--r--src/itemgroup.cpp16
-rw-r--r--src/itemlibrary.cpp2
-rw-r--r--src/katemdi.cpp26
-rw-r--r--src/ktechlab.cpp8
-rw-r--r--src/languages/flowcode.cpp4
-rw-r--r--src/languages/picprogrammer.cpp24
-rw-r--r--src/languages/processchain.cpp2
-rw-r--r--src/languages/sdcc.cpp4
-rw-r--r--src/mechanics/mechanicsgroup.cpp6
-rw-r--r--src/mechanics/mechanicsgroup.h2
-rw-r--r--src/mechanics/mechanicsitem.cpp4
-rw-r--r--src/mechanics/mechanicsitem.h4
-rw-r--r--src/node.h2
-rw-r--r--src/projectmanager.cpp76
-rw-r--r--src/projectmanager.h16
-rw-r--r--src/recentfilesaction.cpp4
-rw-r--r--src/textdocument.cpp4
-rw-r--r--src/textview.cpp2
-rw-r--r--src/variablelabel.cpp2
-rw-r--r--src/viewcontainer.h4
72 files changed, 254 insertions, 254 deletions
diff --git a/src/cnitem.cpp b/src/cnitem.cpp
index 91a7e88..b6d75c9 100644
--- a/src/cnitem.cpp
+++ b/src/cnitem.cpp
@@ -133,8 +133,8 @@ void CNItem::updateNodeLevels()
it.data().node->setLevel(l);
}
- const ItemList::iterator end = m_tqchildren.end();
- for ( ItemList::iterator it = m_tqchildren.begin(); it != end; ++it )
+ const ItemList::iterator end = m_children.end();
+ for ( ItemList::iterator it = m_children.begin(); it != end; ++it )
{
if ( CNItem *cnItem = dynamic_cast<CNItem*>((Item*)*it) )
cnItem->updateNodeLevels();
diff --git a/src/cnitem.h b/src/cnitem.h
index eb8f80a..04fcc62 100644
--- a/src/cnitem.h
+++ b/src/cnitem.h
@@ -165,7 +165,7 @@ protected:
* @param pos is the position that the text occupies relative to the top left corner of the CNItem.
* @param display is the actual text to be displayed.
* @param internal is used to determine the z-level of the text - whether it should be below or above the item
- * @param flags Text tqalignment flags - TQt::AlignmentFlags and TQt::TextFlags OR'd together.
+ * @param flags Text alignment flags - TQt::AlignmentFlags and TQt::TextFlags OR'd together.
*/
Text* addDisplayText( const TQString &id, const TQRect & pos, const TQString &display, bool internal = true, int flags = TQt::AlignHCenter | TQt::AlignVCenter );
void setDisplayText( const TQString &id, const TQString &display );
diff --git a/src/cnitemgroup.h b/src/cnitemgroup.h
index 25dc3ae..18c65e6 100644
--- a/src/cnitemgroup.h
+++ b/src/cnitemgroup.h
@@ -138,13 +138,13 @@ public:
/**
* Returns a list of all the Nodes in the group.
* @param excludeParented if false, then nodes that are fully contained
- * within item tqchildren will also be returned.
+ * within item children will also be returned.
*/
NodeList nodes( bool excludeParented = true ) const;
/**
* Returns a list of all the Connectors in the group.
* @param excludeParented if false, then connectors that are fully contained
- * within item tqchildren will also be returned.
+ * within item children will also be returned.
*/
ConnectorList connectors( bool excludeParented = true ) const;
/**
diff --git a/src/docmanager.cpp b/src/docmanager.cpp
index 35b1c5a..7112a6e 100644
--- a/src/docmanager.cpp
+++ b/src/docmanager.cpp
@@ -99,7 +99,7 @@ Document* DocManager::openURL( const KURL &url, ViewArea *viewArea )
TQFile file(url.path());
if ( file.open(IO_ReadOnly) == false )
{
- KMessageBox::sorry( 0l, i18n("Could not open '%1'").tqarg( url.prettyURL() ) );
+ KMessageBox::sorry( 0l, i18n("Could not open '%1'").arg( url.prettyURL() ) );
return 0l;
}
file.close();
@@ -166,7 +166,7 @@ TQString DocManager::untitledName( int type )
case Document::dt_circuit:
{
if ( m_countCircuit>1 )
- name = i18n("Untitled (Circuit %1)").tqarg(TQString::number(m_countCircuit));
+ name = i18n("Untitled (Circuit %1)").arg(TQString::number(m_countCircuit));
else
name = i18n("Untitled (Circuit)");
m_countCircuit++;
@@ -175,7 +175,7 @@ TQString DocManager::untitledName( int type )
case Document::dt_flowcode:
{
if ( m_countFlowCode>1 )
- name = i18n("Untitled (FlowCode %1)").tqarg(TQString::number(m_countFlowCode));
+ name = i18n("Untitled (FlowCode %1)").arg(TQString::number(m_countFlowCode));
else
name = i18n("Untitled (FlowCode)");
m_countFlowCode++;
@@ -184,7 +184,7 @@ TQString DocManager::untitledName( int type )
case Document::dt_mechanics:
{
if ( m_countMechanics>1 )
- name = i18n("Untitled (Mechanics %1)").tqarg(TQString::number(m_countMechanics));
+ name = i18n("Untitled (Mechanics %1)").arg(TQString::number(m_countMechanics));
else
name = i18n("Untitled (Mechanics)");
m_countMechanics++;
@@ -193,7 +193,7 @@ TQString DocManager::untitledName( int type )
default:
{
if ( m_countOther>1 )
- name = i18n("Untitled (%1)").tqarg(TQString::number(m_countOther));
+ name = i18n("Untitled (%1)").arg(TQString::number(m_countOther));
else
name = i18n("Untitled");
m_countOther++;
@@ -431,7 +431,7 @@ CircuitDocument *DocManager::openCircuitFile( const KURL &url, ViewArea *viewAre
if ( !document->openURL(url) )
{
- KMessageBox::sorry( 0l, i18n("Could not open Circuit file \"%1\"").tqarg(url.prettyURL()) );
+ KMessageBox::sorry( 0l, i18n("Could not open Circuit file \"%1\"").arg(url.prettyURL()) );
document->deleteLater();
return 0l;
}
@@ -448,7 +448,7 @@ FlowCodeDocument *DocManager::openFlowCodeFile( const KURL &url, ViewArea *viewA
if ( !document->openURL(url) )
{
- KMessageBox::sorry( 0l, i18n("Could not open FlowCode file \"%1\"").tqarg(url.prettyURL()) );
+ KMessageBox::sorry( 0l, i18n("Could not open FlowCode file \"%1\"").arg(url.prettyURL()) );
document->deleteLater();
return 0l;
}
@@ -465,7 +465,7 @@ MechanicsDocument *DocManager::openMechanicsFile( const KURL &url, ViewArea *vie
if ( !document->openURL(url) )
{
- KMessageBox::sorry( 0l, i18n("Could not open Mechanics file \"%1\"").tqarg(url.prettyURL()) );
+ KMessageBox::sorry( 0l, i18n("Could not open Mechanics file \"%1\"").arg(url.prettyURL()) );
document->deleteLater();
return 0l;
}
@@ -486,7 +486,7 @@ TextDocument *DocManager::openTextFile( const KURL &url, ViewArea *viewArea )
if ( !document->openURL(url) )
{
- KMessageBox::sorry( 0l, i18n("Could not open text file \"%1\"").tqarg(url.prettyURL()) );
+ KMessageBox::sorry( 0l, i18n("Could not open text file \"%1\"").arg(url.prettyURL()) );
document->deleteLater();
return 0l;
}
diff --git a/src/document.cpp b/src/document.cpp
index 4cd0e6e..d27ecfc 100644
--- a/src/document.cpp
+++ b/src/document.cpp
@@ -110,7 +110,7 @@ bool Document::getURL( const TQString &types )
if ( TQFile::exists( url.path() ) )
{
int query = KMessageBox::warningYesNo( p_ktechlab,
- i18n( "A file named \"%1\" already exists. Are you sure you want to overwrite it?" ).tqarg( url.fileName() ),
+ i18n( "A file named \"%1\" already exists. Are you sure you want to overwrite it?" ).arg( url.fileName() ),
i18n( "Overwrite File?" ),
i18n( "Overwrite" ),
KStdGuiItem::cancel() );
@@ -135,7 +135,7 @@ bool Document::fileClose()
p_ktechlab->tabWidget()->setCurrentPage( p_ktechlab->tabWidget()->indexOf(viewContainer) );
int choice = KMessageBox::warningYesNoCancel( p_ktechlab,
- i18n("The document \'%1\' has been modified.\nDo you want to save it?").tqarg(name),
+ i18n("The document \'%1\' has been modified.\nDo you want to save it?").arg(name),
i18n("Save Document?"),
i18n("Save"),
i18n("Discard") );
diff --git a/src/electronics/component.cpp b/src/electronics/component.cpp
index c05993d..4c8b797 100644
--- a/src/electronics/component.cpp
+++ b/src/electronics/component.cpp
@@ -482,7 +482,7 @@ void Component::initDIPSymbol( const TQStringList & pins, int _width )
}
-// TQString createNode( double _x, double _y, int tqshape, int orientation, const TQString &name, int type, bool isInput = true );
+// TQString createNode( double _x, double _y, int shape, int orientation, const TQString &name, int type, bool isInput = true );
void Component::init1PinLeft( int h1 )
{
diff --git a/src/electronics/component.h b/src/electronics/component.h
index 8a30315..a2b215f 100644
--- a/src/electronics/component.h
+++ b/src/electronics/component.h
@@ -244,7 +244,7 @@ class Component : public CNItem
protected:
/**
- * Convenience functionality provided for components in a port tqshape
+ * Convenience functionality provided for components in a port shape
* (such as ParallelPortComponent and SerialPortComponent).
*/
void drawPortShape( TQPainter & p );
@@ -263,7 +263,7 @@ class Component : public CNItem
void initDIP( const TQStringList & pins );
/**
* Creates the DIP symbol:
- * @li constructs rectangular tqshape
+ * @li constructs rectangular shape
* @li puts on text labels in appropriate positions from TQStringList pins
*/
void initDIPSymbol( const TQStringList & pins, int width );
diff --git a/src/electronics/components/bussplitter.cpp b/src/electronics/components/bussplitter.cpp
index 85619a4..6eb58e8 100644
--- a/src/electronics/components/bussplitter.cpp
+++ b/src/electronics/components/bussplitter.cpp
@@ -107,7 +107,7 @@ void BusSplitter::dataChanged()
TQString BusSplitter::outNodeID( unsigned node ) const
{
- return TQString("out_%1").tqarg(TQString::number(node));
+ return TQString("out_%1").arg(TQString::number(node));
}
diff --git a/src/electronics/components/eckeypad.cpp b/src/electronics/components/eckeypad.cpp
index c92a562..4a0ec7b 100644
--- a/src/electronics/components/eckeypad.cpp
+++ b/src/electronics/components/eckeypad.cpp
@@ -66,7 +66,7 @@ ECKeyPad::ECKeyPad( ICNDocument *icnDocument, bool newItem, const char *id )
v->setValue(5e-3);
for ( int i = 0; i < 4; i++ )
- createPin( 0, -32+i*24, 0, TQString("row_%1").tqarg(TQString::number(i)) );
+ createPin( 0, -32+i*24, 0, TQString("row_%1").arg(TQString::number(i)) );
m_numCols = 0;
}
@@ -79,7 +79,7 @@ ECKeyPad::~ECKeyPad()
TQString ECKeyPad::buttonID( int row, int col ) const
{
- return TQString("b_%1_%2").tqarg(TQString::number(row)).tqarg(TQString::number(col));
+ return TQString("b_%1_%2").arg(TQString::number(row)).arg(TQString::number(col));
}
diff --git a/src/electronics/components/magnitudecomparator.cpp b/src/electronics/components/magnitudecomparator.cpp
index 3e1f8f9..bae9b12 100644
--- a/src/electronics/components/magnitudecomparator.cpp
+++ b/src/electronics/components/magnitudecomparator.cpp
@@ -119,9 +119,9 @@ void MagnitudeComparator::initPins()
for ( int i = 0; i < space; i++ )
leftPins << "";
for ( int i = 0; i < newABLogicCount; i++ )
- leftPins << TQString("A%1").tqarg( TQString::number(i) );
+ leftPins << TQString("A%1").arg( TQString::number(i) );
for ( int i = 0; i < newABLogicCount; i++ )
- leftPins << TQString("B%1").tqarg( TQString::number(i) );
+ leftPins << TQString("B%1").arg( TQString::number(i) );
for ( int i = 0; i < space; i++ )
leftPins << "";
diff --git a/src/electronics/components/matrixdisplay.cpp b/src/electronics/components/matrixdisplay.cpp
index c2a271d..4ba3dc6 100644
--- a/src/electronics/components/matrixdisplay.cpp
+++ b/src/electronics/components/matrixdisplay.cpp
@@ -223,11 +223,11 @@ void MatrixDisplay::initPins( unsigned numRows, unsigned numCols )
TQString MatrixDisplay::colPinID( int col ) const
{
- return TQString("col_%1").tqarg(TQString::number(col));
+ return TQString("col_%1").arg(TQString::number(col));
}
TQString MatrixDisplay::rowPinID( int row ) const
{
- return TQString("row_%1").tqarg(TQString::number(row));
+ return TQString("row_%1").arg(TQString::number(row));
}
diff --git a/src/electronics/components/parallelportcomponent.cpp b/src/electronics/components/parallelportcomponent.cpp
index 22f1584..6126c1e 100644
--- a/src/electronics/components/parallelportcomponent.cpp
+++ b/src/electronics/components/parallelportcomponent.cpp
@@ -87,7 +87,7 @@ ParallelPortComponent::ParallelPortComponent( ICNDocument *icnDocument, bool new
//BEGIN Data register
for ( int i = 0; i < 8; ++i )
{
- TQString id = TQString("D%1").tqarg(i);
+ TQString id = TQString("D%1").arg(i);
TQString name = id;
pin = createPin( -40, -80 + 16*i, 0, id );
@@ -167,7 +167,7 @@ ParallelPortComponent::ParallelPortComponent( ICNDocument *icnDocument, bool new
// And make the rest of the pins ground
for ( int i = 0; i < 8; ++i )
{
- pin = createPin( 40, -24 + i*16, 180, TQString("GND%1").tqarg( i ) );
+ pin = createPin( 40, -24 + i*16, 180, TQString("GND%1").arg( i ) );
pin->pin()->setGroundType( Pin::gt_always );
}
#endif
@@ -200,7 +200,7 @@ void ParallelPortComponent::initPort( const TQString & port )
if ( ! m_pParallelPort->openPort( port ) )
{
- p_itemDocument->canvas()->setMessage( i18n("Could not open port %1").tqarg( port ) );
+ p_itemDocument->canvas()->setMessage( i18n("Could not open port %1").arg( port ) );
return;
}
}
diff --git a/src/electronics/components/piccomponent.cpp b/src/electronics/components/piccomponent.cpp
index b1d39bc..00a32c3 100644
--- a/src/electronics/components/piccomponent.cpp
+++ b/src/electronics/components/piccomponent.cpp
@@ -159,14 +159,14 @@ void PICComponent::initPIC( bool forceReload )
case GpsimProcessor::DoesntExist:
if ( newProgram == _def_PICComponent_fileName && !newProgram.isEmpty() )
break;
- KMessageBox::sorry( 0l, i18n("The file \"%1\" does not exist.").tqarg( newProgram ) );
+ KMessageBox::sorry( 0l, i18n("The file \"%1\" does not exist.").arg( newProgram ) );
m_picFile = TQString();
break;
case GpsimProcessor::IncorrectType:
if ( newProgram == _def_PICComponent_fileName && !newProgram.isEmpty() )
break;
- KMessageBox::sorry( 0L, i18n("\"%1\" is not a valid PIC program.\nThe file must exist, and the extension should be \".cod\", \".asm\", \".flowcode\", \".basic\", \".microbe\" or \".c\".\n\".hex\" is allowed, provided that there is a corresponding \".cod\" file.").tqarg(newProgram) );
+ KMessageBox::sorry( 0L, i18n("\"%1\" is not a valid PIC program.\nThe file must exist, and the extension should be \".cod\", \".asm\", \".flowcode\", \".basic\", \".microbe\" or \".c\".\n\".hex\" is allowed, provided that there is a corresponding \".cod\" file.").arg(newProgram) );
m_picFile = TQString();
break;
diff --git a/src/electronics/components/ram.cpp b/src/electronics/components/ram.cpp
index a8b259e..d0ac2b1 100644
--- a/src/electronics/components/ram.cpp
+++ b/src/electronics/components/ram.cpp
@@ -128,13 +128,13 @@ void RAM::initPins()
TQStringList leftPins; // Pins on left of IC
leftPins << "CS" << "OE" << "WE";
for ( int i = 0; i < newAddressSize; ++i )
- leftPins << TQString("A%1").tqarg( TQString::number(i) );
+ leftPins << TQString("A%1").arg( TQString::number(i) );
TQStringList rightPins; // Pins on right of IC
for ( unsigned i = newWordSize; i > 0; --i )
- rightPins << TQString("DI%1").tqarg( TQString::number(i-1) );
+ rightPins << TQString("DI%1").arg( TQString::number(i-1) );
for ( unsigned i = newWordSize; i > 0; --i )
- rightPins << TQString("DO%1").tqarg( TQString::number(i-1) );
+ rightPins << TQString("DO%1").arg( TQString::number(i-1) );
// Make pin lists of consistent sizes
for ( unsigned i = leftPins.size(); i < rightPins.size(); ++i )
@@ -177,11 +177,11 @@ void RAM::initPins()
for ( int i = oldWordSize; i < newWordSize; ++i )
{
- node = ecNodeWithID( TQString("DI%1").tqarg( TQString::number(i) ) );
+ node = ecNodeWithID( TQString("DI%1").arg( TQString::number(i) ) );
m_dataIn.insert( i, createLogicIn(node) );
m_dataIn[i]->setCallback( this, (CallbackPtr)(&RAM::inStateChanged) );
- node = ecNodeWithID( TQString("DO%1").tqarg( TQString::number(i) ) );
+ node = ecNodeWithID( TQString("DO%1").arg( TQString::number(i) ) );
m_dataOut.insert( i, createLogicOut(node, false) );
}
}
@@ -189,12 +189,12 @@ void RAM::initPins()
{
for ( int i = newWordSize; i < oldWordSize; ++i )
{
- TQString id = TQString("DO%1").tqarg( TQString::number(i) );
+ TQString id = TQString("DO%1").arg( TQString::number(i) );
removeDisplayText(id);
removeElement( m_dataIn[i], false );
removeNode(id);
- id = TQString("DI%1").tqarg( TQString::number(i) );
+ id = TQString("DI%1").arg( TQString::number(i) );
removeDisplayText(id);
removeElement( m_dataOut[i], false );
removeNode(id);
@@ -210,7 +210,7 @@ void RAM::initPins()
for ( int i = oldAddressSize; i < newAddressSize; ++i )
{
- node = ecNodeWithID( TQString("A%1").tqarg( TQString::number(i) ) );
+ node = ecNodeWithID( TQString("A%1").arg( TQString::number(i) ) );
m_address.insert( i, createLogicIn(node) );
m_address[i]->setCallback( this, (CallbackPtr)(&RAM::inStateChanged) );
}
@@ -219,7 +219,7 @@ void RAM::initPins()
{
for ( int i = newAddressSize; i < oldAddressSize; ++i )
{
- TQString id = TQString("A%1").tqarg( TQString::number(i) );
+ TQString id = TQString("A%1").arg( TQString::number(i) );
removeDisplayText(id);
removeElement( m_address[i], false );
removeNode(id);
diff --git a/src/electronics/components/rotoswitch.cpp b/src/electronics/components/rotoswitch.cpp
index ac7f1a0..738942b 100644
--- a/src/electronics/components/rotoswitch.cpp
+++ b/src/electronics/components/rotoswitch.cpp
@@ -245,7 +245,7 @@ void ECRotoSwitch::setUpSwitches()
for(int i=0; i<m_numPositions; i++)
{
SwitchPosition& sp = m_positions[i];
- TQString pinName = TQString("pin_%1").tqarg(i);
+ TQString pinName = TQString("pin_%1").arg(i);
removeNode(pinName);
removeSwitch(sp.posSwitch);
}
@@ -284,7 +284,7 @@ void ECRotoSwitch::setUpSwitches()
// kdDebug() << contactX <<", "<< contactY <<endl;
- sp.node = createPin(contactX,-contactY,sp.pinAngle,TQString("pin_%1").tqarg(i));
+ sp.node = createPin(contactX,-contactY,sp.pinAngle,TQString("pin_%1").arg(i));
sp.posSwitch = createSwitch(m_inNode, sp.node, true);
sp.isMomentary = false;//(map[i] == 'M');
m_positions.push_back(sp);
diff --git a/src/electronics/components/serialportcomponent.cpp b/src/electronics/components/serialportcomponent.cpp
index 6e6bfed..4e3a221 100644
--- a/src/electronics/components/serialportcomponent.cpp
+++ b/src/electronics/components/serialportcomponent.cpp
@@ -197,7 +197,7 @@ void SerialPortComponent::initPort( const TQString & port, unsigned baudRate )
if ( ! m_pSerialPort->openPort( port, baudRate ) )
{
- p_itemDocument->canvas()->setMessage( i18n("Could not open port %1").tqarg( port ) );
+ p_itemDocument->canvas()->setMessage( i18n("Could not open port %1").arg( port ) );
return;
}
}
diff --git a/src/electronics/gpsimprocessor.cpp b/src/electronics/gpsimprocessor.cpp
index 8e2ccfa..76fc20b 100644
--- a/src/electronics/gpsimprocessor.cpp
+++ b/src/electronics/gpsimprocessor.cpp
@@ -161,26 +161,26 @@ void GpsimProcessor::displayCodLoadStatus( )
case CodSuccess:
break;
case CodFileNotFound:
- KMessageBox::sorry( 0l, i18n("The cod file \"%1\" was not found.").tqarg(m_symbolFile), i18n("File Not Found") );
+ KMessageBox::sorry( 0l, i18n("The cod file \"%1\" was not found.").arg(m_symbolFile), i18n("File Not Found") );
break;
case CodUnrecognizedProcessor:
- KMessageBox::sorry( 0l, i18n("The processor for cod file \"%1\" is unrecognized.").tqarg(m_symbolFile), i18n("Unrecognized Processor") );
+ KMessageBox::sorry( 0l, i18n("The processor for cod file \"%1\" is unrecognized.").arg(m_symbolFile), i18n("Unrecognized Processor") );
break;
case CodFileNameTooLong:
- KMessageBox::sorry( 0l, i18n("The file name \"%1\" is too long.").tqarg(m_symbolFile), i18n("Filename Too Long") );
+ KMessageBox::sorry( 0l, i18n("The file name \"%1\" is too long.").arg(m_symbolFile), i18n("Filename Too Long") );
break;
case CodLstNotFound:
- KMessageBox::sorry( 0l, i18n("The lst file associated with the cod file \"%1\" was not found.").tqarg(m_symbolFile), i18n("LST File Not Found") );
+ KMessageBox::sorry( 0l, i18n("The lst file associated with the cod file \"%1\" was not found.").arg(m_symbolFile), i18n("LST File Not Found") );
break;
case CodBadFile:
- KMessageBox::sorry( 0l, i18n("The cod file \"%1\" is bad.").tqarg(m_symbolFile), i18n("Bad File") );
+ KMessageBox::sorry( 0l, i18n("The cod file \"%1\" is bad.").arg(m_symbolFile), i18n("Bad File") );
break;
case CodFileUnreadable:
- KMessageBox::sorry( 0l, i18n("The cod file \"%1\" could not be read from.").tqarg(m_symbolFile), i18n("Unreadable File") );
+ KMessageBox::sorry( 0l, i18n("The cod file \"%1\" could not be read from.").arg(m_symbolFile), i18n("Unreadable File") );
break;
case CodFailure:
case CodUnknown:
- KMessageBox::sorry( 0l, i18n("An error occured with the cod file \"%1\".").tqarg(m_symbolFile), i18n("Error") );
+ KMessageBox::sorry( 0l, i18n("An error occured with the cod file \"%1\".").arg(m_symbolFile), i18n("Error") );
break;
}
}
diff --git a/src/electronics/port.cpp b/src/electronics/port.cpp
index 124fe1d..8a92402 100644
--- a/src/electronics/port.cpp
+++ b/src/electronics/port.cpp
@@ -207,28 +207,28 @@ TQStringList SerialPort::ports( unsigned probeResult )
for ( int i = 0; i < 8; ++i )
{
- TQString dev = TQString("/dev/ttyS%1").tqarg(i);
+ TQString dev = TQString("/dev/ttyS%1").arg(i);
if ( probe(dev) & probeResult )
list << dev;
}
for ( unsigned i = 0; i < 8; ++i )
{
- TQString dev = TQString("/dev/tts/%1").tqarg(i);
+ TQString dev = TQString("/dev/tts/%1").arg(i);
if ( probe(dev) & probeResult )
list << dev;
}
for ( unsigned i = 0; i < 8; ++i )
{
- TQString dev = TQString("/dev/ttyUSB%1").tqarg(i);
+ TQString dev = TQString("/dev/ttyUSB%1").arg(i);
if ( probe(dev) & probeResult )
list << dev;
}
for ( unsigned i = 0; i < 8; ++i )
{
- TQString dev = TQString("/dev/usb/tts/%1").tqarg(i);
+ TQString dev = TQString("/dev/usb/tts/%1").arg(i);
if ( probe(dev) & probeResult )
list << dev;
}
@@ -453,14 +453,14 @@ TQStringList ParallelPort::ports( unsigned probeResult )
for ( unsigned i = 0; i < 8; ++i )
{
- TQString dev = TQString("/dev/parport%1").tqarg(i);
+ TQString dev = TQString("/dev/parport%1").arg(i);
if ( probe(dev) & probeResult )
list << dev;
}
for ( unsigned i = 0; i < 8; ++i )
{
- TQString dev = TQString("/dev/parports/%1").tqarg(i);
+ TQString dev = TQString("/dev/parports/%1").arg(i);
if ( probe(dev) & probeResult )
list << dev;
}
diff --git a/src/flowcontainer.cpp b/src/flowcontainer.cpp
index d9291d6..22c2db8 100644
--- a/src/flowcontainer.cpp
+++ b/src/flowcontainer.cpp
@@ -374,8 +374,8 @@ void FlowContainer::updateContainedVisibility()
if (m_ext_out)
m_ext_out->setVisible( isVisible() );
- const ItemList::iterator cEnd = m_tqchildren.end();
- for ( ItemList::iterator it = m_tqchildren.begin(); it != cEnd; ++it )
+ const ItemList::iterator cEnd = m_children.end();
+ for ( ItemList::iterator it = m_children.begin(); it != cEnd; ++it )
{
if (*it)
(*it)->setVisible( isVisible() && b_expanded );
@@ -384,7 +384,7 @@ void FlowContainer::updateContainedVisibility()
m_rectangularOverlay->setVisible( isVisible() && b_expanded );
NodeGroupList hidableNodeGroups;
- p_icnDocument->getTranslatable( tqchildren(true) += GuardedItem(this), 0, 0, &hidableNodeGroups );
+ p_icnDocument->getTranslatable( children(true) += GuardedItem(this), 0, 0, &hidableNodeGroups );
NodeGroupList::iterator hngEnd = hidableNodeGroups.end();
for ( NodeGroupList::iterator it = hidableNodeGroups.begin(); it != hngEnd; ++it )
diff --git a/src/flowparts/callsub.cpp b/src/flowparts/callsub.cpp
index 09687e2..2b2d30b 100644
--- a/src/flowparts/callsub.cpp
+++ b/src/flowparts/callsub.cpp
@@ -51,7 +51,7 @@ CallSub::~CallSub()
void CallSub::dataChanged()
{
- setCaption( i18n("Call %1").tqarg(dataString("sub")) );
+ setCaption( i18n("Call %1").arg(dataString("sub")) );
}
void CallSub::generateMicrobe( FlowCode *code )
diff --git a/src/flowparts/count.cpp b/src/flowparts/count.cpp
index 2357fb8..e4bbdc3 100644
--- a/src/flowparts/count.cpp
+++ b/src/flowparts/count.cpp
@@ -58,7 +58,7 @@ Count::~Count()
void Count::dataChanged()
{
double count = dataDouble("1-length");
- setCaption( i18n("Count %1 for %2 sec").tqarg(dataString("0-trigger")).tqarg(TQString::number( count / getMultiplier(count), 'g', 3 ) + getNumberMag(count)) );
+ setCaption( i18n("Count %1 for %2 sec").arg(dataString("0-trigger")).arg(TQString::number( count / getMultiplier(count), 'g', 3 ) + getNumberMag(count)) );
}
void Count::generateMicrobe( FlowCode *code )
diff --git a/src/flowparts/delay.cpp b/src/flowparts/delay.cpp
index f31a0e9..ae85595 100644
--- a/src/flowparts/delay.cpp
+++ b/src/flowparts/delay.cpp
@@ -53,7 +53,7 @@ Delay::~Delay()
void Delay::dataChanged()
{
double delay = dataDouble("delay_length");
- setCaption( i18n("Delay for %1 sec").tqarg(TQString::number( delay / getMultiplier(delay), 'g', 3 )+getNumberMag(delay)) );
+ setCaption( i18n("Delay for %1 sec").arg(TQString::number( delay / getMultiplier(delay), 'g', 3 )+getNumberMag(delay)) );
}
void Delay::generateMicrobe( FlowCode *code )
diff --git a/src/flowparts/embed.cpp b/src/flowparts/embed.cpp
index f6bb3b2..7e5f3a3 100644
--- a/src/flowparts/embed.cpp
+++ b/src/flowparts/embed.cpp
@@ -59,7 +59,7 @@ Embed::~Embed()
void Embed::dataChanged()
{
const TQString sample = dataString("code").left(10).replace("\n"," ");
- setCaption( i18n("%1: %2...").tqarg(dataString("type")).tqarg(sample) );
+ setCaption( i18n("%1: %2...").arg(dataString("type")).arg(sample) );
}
diff --git a/src/flowparts/flowpart.cpp b/src/flowparts/flowpart.cpp
index 1ec4a6e..d19ce45 100644
--- a/src/flowparts/flowpart.cpp
+++ b/src/flowparts/flowpart.cpp
@@ -186,7 +186,7 @@ void FlowPart::initSymbol( FlowPart::FlowSymbol symbol, int width )
case FlowPart::ps_io:
{
- // define parallelogram tqshape
+ // define parallelogram shape
TQPointArray pa(4);
pa[0] = TQPoint( -(width-10)/2, -16 );
pa[1] = TQPoint( width/2, -16 );
@@ -292,7 +292,7 @@ void FlowPart::drawShape( TQPainter &p )
case FlowPart::ps_decision:
{
- // TODO Make the tqshape nice and pretty with rounded corners
+ // TODO Make the shape nice and pretty with rounded corners
CNItem::drawShape(p);
break;
}
diff --git a/src/flowparts/flowpart.h b/src/flowparts/flowpart.h
index afa20c8..9cd2553 100644
--- a/src/flowparts/flowpart.h
+++ b/src/flowparts/flowpart.h
@@ -42,8 +42,8 @@ public:
ps_call, // Call - Rectangular box with double vertical lines at either end
ps_io, // I/O - Slanter rectangular box
ps_round, // Start/End - Rounded rectangular box
- ps_decision, // Decision - Diamond tqshape
- ps_other // Custom tqshape, which is ignored by FlowPart
+ ps_decision, // Decision - Diamond shape
+ ps_other // Custom shape, which is ignored by FlowPart
};
FlowPart( ICNDocument *icnDocument, bool newItem, const TQString &id );
virtual ~FlowPart();
@@ -167,7 +167,7 @@ protected:
*/
void createAltOutput();
/**
- * Initialises a symbol, by calling setItemPoints with the tqshape
+ * Initialises a symbol, by calling setItemPoints with the shape
*/
void initSymbol( FlowPart::FlowSymbol symbol, int width = 48 );
diff --git a/src/flowparts/inputbutton.cpp b/src/flowparts/inputbutton.cpp
index a140a2a..d7c2a98 100644
--- a/src/flowparts/inputbutton.cpp
+++ b/src/flowparts/inputbutton.cpp
@@ -59,7 +59,7 @@ InputButton::~InputButton()
void InputButton::dataChanged()
{
- setCaption( i18n("Continue on %1 %2").tqarg(dataString("0-trigger")).tqarg(dataString("1-pin")) );
+ setCaption( i18n("Continue on %1 %2").arg(dataString("0-trigger")).arg(dataString("1-pin")) );
}
diff --git a/src/flowparts/interrupt.cpp b/src/flowparts/interrupt.cpp
index 14a783f..9325c33 100644
--- a/src/flowparts/interrupt.cpp
+++ b/src/flowparts/interrupt.cpp
@@ -55,7 +55,7 @@ Interrupt::~Interrupt()
void Interrupt::dataChanged()
{
- setCaption( i18n("Interrupt %1").tqarg(dataString("interrupt")) );
+ setCaption( i18n("Interrupt %1").arg(dataString("interrupt")) );
}
void Interrupt::generateMicrobe( FlowCode *code )
diff --git a/src/flowparts/keypad.cpp b/src/flowparts/keypad.cpp
index 8e49e29..47e6f30 100644
--- a/src/flowparts/keypad.cpp
+++ b/src/flowparts/keypad.cpp
@@ -55,12 +55,12 @@ Keypad::~Keypad()
void Keypad::dataChanged()
{
- setCaption( i18n("Read %1 to %2").tqarg( dataString( "keypad" ) ).tqarg( dataString( "variable" ) ) );
+ setCaption( i18n("Read %1 to %2").arg( dataString( "keypad" ) ).arg( dataString( "variable" ) ) );
}
void Keypad::generateMicrobe( FlowCode *code )
{
- code->addCode( TQString("%1 = %2").tqarg( dataString("variable") ).tqarg( dataString("keypad") ) );
+ code->addCode( TQString("%1 = %2").arg( dataString("variable") ).arg( dataString("keypad") ) );
code->addCodeBranch( outputPart("stdoutput") );
}
diff --git a/src/flowparts/pinmapping.cpp b/src/flowparts/pinmapping.cpp
index 289cbc4..5b9675d 100644
--- a/src/flowparts/pinmapping.cpp
+++ b/src/flowparts/pinmapping.cpp
@@ -186,10 +186,10 @@ void PinMapDocument::init( const PinMapping & pinMapping, MicroInfo * microInfo
{
TQStringList::const_iterator it = pins.begin();
for ( unsigned row = 0; (row < 4) && (it != end); ++row, ++it )
- createConnector( m_pKeypad->childNode( TQString("row_%1").tqarg( row ) ), m_pPicComponent->childNode( *it ) );
+ createConnector( m_pKeypad->childNode( TQString("row_%1").arg( row ) ), m_pPicComponent->childNode( *it ) );
for ( unsigned col = 0; (col < keypadCols) && (it != end); ++col, ++it )
- createConnector( m_pKeypad->childNode( TQString("col_%1").tqarg( col ) ), m_pPicComponent->childNode( *it ) );
+ createConnector( m_pKeypad->childNode( TQString("col_%1").arg( col ) ), m_pPicComponent->childNode( *it ) );
}
clearHistory(); // Don't allow undoing of initial creation of stuff
@@ -255,17 +255,17 @@ PinMapping PinMapDocument::pinMapping() const
case PinMapping::Keypad_4x3:
for ( unsigned i = 0; i < 4; ++i )
- attachedIDs << TQString("row_%1").tqarg(i);
+ attachedIDs << TQString("row_%1").arg(i);
for ( unsigned i = 0; i < 3; ++i )
- attachedIDs << TQString("col_%1").tqarg(i);
+ attachedIDs << TQString("col_%1").arg(i);
attached = m_pKeypad;
break;
case PinMapping::Keypad_4x4:
for ( unsigned i = 0; i < 4; ++i )
- attachedIDs << TQString("row_%1").tqarg(i);
+ attachedIDs << TQString("row_%1").arg(i);
for ( unsigned i = 0; i < 4; ++i )
- attachedIDs << TQString("col_%1").tqarg(i);
+ attachedIDs << TQString("col_%1").arg(i);
attached = m_pKeypad;
break;
diff --git a/src/flowparts/pulse.cpp b/src/flowparts/pulse.cpp
index 86e2239..77f9dd0 100644
--- a/src/flowparts/pulse.cpp
+++ b/src/flowparts/pulse.cpp
@@ -68,7 +68,7 @@ Pulse::~Pulse()
void Pulse::dataChanged()
{
double pulse = dataDouble("0-duration");
- setCaption( i18n("Pulse %1 for %2 sec").tqarg(dataString("3-pin")).tqarg(TQString::number( pulse / getMultiplier(pulse), 'f', 1 ) + getNumberMag(pulse)) );
+ setCaption( i18n("Pulse %1 for %2 sec").arg(dataString("3-pin")).arg(TQString::number( pulse / getMultiplier(pulse), 'f', 1 ) + getNumberMag(pulse)) );
}
void Pulse::generateMicrobe( FlowCode *code )
diff --git a/src/flowparts/readport.cpp b/src/flowparts/readport.cpp
index 45623be..4385c58 100644
--- a/src/flowparts/readport.cpp
+++ b/src/flowparts/readport.cpp
@@ -58,7 +58,7 @@ ReadPort::~ReadPort()
void ReadPort::dataChanged()
{
- setCaption( i18n("Read %1 to %2").tqarg(dataString("0-port")).tqarg(dataString("1-var")) );
+ setCaption( i18n("Read %1 to %2").arg(dataString("0-port")).arg(dataString("1-var")) );
}
void ReadPort::generateMicrobe( FlowCode *code )
diff --git a/src/flowparts/repeat.cpp b/src/flowparts/repeat.cpp
index 53529ac..3dda0ae 100644
--- a/src/flowparts/repeat.cpp
+++ b/src/flowparts/repeat.cpp
@@ -62,7 +62,7 @@ Repeat::~Repeat()
void Repeat::dataChanged()
{
- setCaption( i18n("repeat until %1 %2 %3").tqarg(dataString("0var1")).tqarg(dataString("1op")).tqarg(dataString("2var2")) );
+ setCaption( i18n("repeat until %1 %2 %3").arg(dataString("0var1")).arg(dataString("1op")).arg(dataString("2var2")) );
}
void Repeat::generateMicrobe( FlowCode *code )
diff --git a/src/flowparts/setpin.cpp b/src/flowparts/setpin.cpp
index 81c29ca..be826da 100644
--- a/src/flowparts/setpin.cpp
+++ b/src/flowparts/setpin.cpp
@@ -59,7 +59,7 @@ SetPin::~SetPin()
void SetPin::dataChanged()
{
- setCaption( i18n("Set %1 %2").tqarg(dataString("pin")).tqarg(dataString("state")) );
+ setCaption( i18n("Set %1 %2").arg(dataString("pin")).arg(dataString("state")) );
}
void SetPin::generateMicrobe( FlowCode *code )
diff --git a/src/flowparts/sevenseg.cpp b/src/flowparts/sevenseg.cpp
index 1f85e19..90a4e7e 100644
--- a/src/flowparts/sevenseg.cpp
+++ b/src/flowparts/sevenseg.cpp
@@ -59,13 +59,13 @@ SevenSeg::~SevenSeg()
void SevenSeg::dataChanged()
{
- setCaption( i18n("Display %1 on %2").tqarg( dataString("expression") ).tqarg( dataString("sevenseg") ) );
+ setCaption( i18n("Display %1 on %2").arg( dataString("expression") ).arg( dataString("sevenseg") ) );
}
void SevenSeg::generateMicrobe( FlowCode *code )
{
- code->addCode( TQString("%1 = %2").tqarg( dataString("sevenseg") ).tqarg( dataString("expression") ) );
+ code->addCode( TQString("%1 = %2").arg( dataString("sevenseg") ).arg( dataString("expression") ) );
code->addCodeBranch( outputPart("stdoutput") );
}
diff --git a/src/flowparts/while.cpp b/src/flowparts/while.cpp
index ddcf981..be2189d 100644
--- a/src/flowparts/while.cpp
+++ b/src/flowparts/while.cpp
@@ -62,7 +62,7 @@ While::~While()
void While::dataChanged()
{
- setCaption( i18n("while %1 %2 %3").tqarg(dataString("0var1")).tqarg(dataString("1op")).tqarg(dataString("2var2")) );
+ setCaption( i18n("while %1 %2 %3").arg(dataString("0var1")).arg(dataString("1op")).arg(dataString("2var2")) );
}
void While::generateMicrobe( FlowCode *code )
diff --git a/src/flowparts/writeport.cpp b/src/flowparts/writeport.cpp
index 312ea01..9816f69 100644
--- a/src/flowparts/writeport.cpp
+++ b/src/flowparts/writeport.cpp
@@ -59,7 +59,7 @@ WritePort::~WritePort()
void WritePort::dataChanged()
{
- setCaption( i18n("Write %1 to %2").tqarg(dataString("0-var")).tqarg(dataString("1-port")) );
+ setCaption( i18n("Write %1 to %2").arg(dataString("0-var")).arg(dataString("1-port")) );
}
diff --git a/src/gui/generaloptionswidget.ui b/src/gui/generaloptionswidget.ui
index 201a567..08c1de2 100644
--- a/src/gui/generaloptionswidget.ui
+++ b/src/gui/generaloptionswidget.ui
@@ -217,7 +217,7 @@
<property name="scaledContents">
<bool>false</bool>
</property>
- <property name="tqalignment">
+ <property name="alignment">
<set>WordBreak|AlignVCenter</set>
</property>
</widget>
diff --git a/src/gui/itemselector.cpp b/src/gui/itemselector.cpp
index 539bc40..89f5bb2 100644
--- a/src/gui/itemselector.cpp
+++ b/src/gui/itemselector.cpp
@@ -163,7 +163,7 @@ void ItemSelector::slotContextMenuRequested( TQListViewItem* item, const TQPoint
}
TQPopupMenu *menu = new TQPopupMenu(this);
- menu->insertItem( i18n("Remove %1").tqarg(item->text(0)), this, TQT_SLOT(slotRemoveSelectedItem()), TQt::Key_Delete );
+ menu->insertItem( i18n("Remove %1").arg(item->text(0)), this, TQT_SLOT(slotRemoveSelectedItem()), TQt::Key_Delete );
menu->popup(pos);
}
@@ -177,7 +177,7 @@ void ItemSelector::slotRemoveSelectedItem()
emit itemRemoved( item->key( 0, 0 ) );
ILVItem *parent = dynamic_cast<ILVItem*>(item->TQListViewItem::parent());
delete item;
- // Get rid of the category as well if it has no tqchildren
+ // Get rid of the category as well if it has no children
if ( parent && !parent->firstChild() )
{
m_categories.remove(parent->text(0));
diff --git a/src/gui/logicwidget.ui b/src/gui/logicwidget.ui
index 99ef045..e57feab 100644
--- a/src/gui/logicwidget.ui
+++ b/src/gui/logicwidget.ui
@@ -239,7 +239,7 @@
These values will apply to all components, apart from the PIC, whose pins' impedances depend on the pin in use.</string>
</property>
- <property name="tqalignment">
+ <property name="alignment">
<set>WordBreak|AlignVCenter</set>
</property>
</widget>
diff --git a/src/gui/logview.cpp b/src/gui/logview.cpp
index 574d967..2da75a2 100644
--- a/src/gui/logview.cpp
+++ b/src/gui/logview.cpp
@@ -49,23 +49,23 @@ void LogView::addOutput( TQString text, OutputType outputType, MessageInfo messa
switch(outputType)
{
case LogView::ot_important:
- append( TQString("<font color=\"#000000\"><b>%1</b></font>").tqarg(text) );
+ append( TQString("<font color=\"#000000\"><b>%1</b></font>").arg(text) );
break;
case LogView::ot_info:
- append( TQString("<font color=\"#000000\"><i>%1</i></font>").tqarg(text) );
+ append( TQString("<font color=\"#000000\"><i>%1</i></font>").arg(text) );
break;
case LogView::ot_message:
- append( TQString("<font color=\"#000000\">%1</font>").tqarg(text) );
+ append( TQString("<font color=\"#000000\">%1</font>").arg(text) );
break;
case LogView::ot_warning:
- append( TQString("<font color=\"#666666\">%1</font>").tqarg(text) );
+ append( TQString("<font color=\"#666666\">%1</font>").arg(text) );
break;
case LogView::ot_error:
- append( TQString("<font color=\"#800000\">%1</font>").tqarg(text) );
+ append( TQString("<font color=\"#800000\">%1</font>").arg(text) );
break;
}
diff --git a/src/gui/microsettingsdlg.cpp b/src/gui/microsettingsdlg.cpp
index 55ef185..318c3ea 100644
--- a/src/gui/microsettingsdlg.cpp
+++ b/src/gui/microsettingsdlg.cpp
@@ -376,7 +376,7 @@ void MicroSettingsDlg::savePort( int row )
if ( !typeOk )
{
-// KMessageBox::sorry( this, i18n("Unregnised Port Type: %1").tqarg(typeText) );
+// KMessageBox::sorry( this, i18n("Unregnised Port Type: %1").arg(typeText) );
return;
}
@@ -389,7 +389,7 @@ void MicroSettingsDlg::savePort( int row )
if ( !stateOk )
{
-// KMessageBox::sorry( this, i18n("Unregnised Port State: %1").tqarg(stateText) );
+// KMessageBox::sorry( this, i18n("Unregnised Port State: %1").arg(stateText) );
return;
}
@@ -411,7 +411,7 @@ void MicroSettingsDlg::saveVariable( int row )
if (!ok)
{
- KMessageBox::sorry( this, i18n("Invalid variable value: %1").tqarg(valueText) );
+ KMessageBox::sorry( this, i18n("Invalid variable value: %1").arg(valueText) );
return;
}
diff --git a/src/gui/newfilewidget.ui b/src/gui/newfilewidget.ui
index 94df077..4f0b4dc 100644
--- a/src/gui/newfilewidget.ui
+++ b/src/gui/newfilewidget.ui
@@ -59,7 +59,7 @@ Creates a new circuit, with drag and drop editor. Real time simulation of the ci
<property name="text">
<string>File Type:</string>
</property>
- <property name="tqalignment">
+ <property name="alignment">
<set>AlignVCenter</set>
</property>
</widget>
diff --git a/src/gui/oscilloscopeview.cpp b/src/gui/oscilloscopeview.cpp
index f74a822..e42af21 100644
--- a/src/gui/oscilloscopeview.cpp
+++ b/src/gui/oscilloscopeview.cpp
@@ -77,7 +77,7 @@ void OscilloscopeView::updateView()
void OscilloscopeView::updateViewTimeout()
{
b_needRedraw = true;
- tqrepaint(false);
+ repaint(false);
updateTimeLabel();
}
@@ -130,7 +130,7 @@ void OscilloscopeView::mousePressEvent( TQMouseEvent *event )
for ( uint i=0; i<5; ++i )
{
const int num = fps[i];
- fpsMenu.insertItem( i18n("%1 fps").tqarg(num), num );
+ fpsMenu.insertItem( i18n("%1 fps").arg(num), num );
fpsMenu.setItemChecked( num, num == m_fps );
}
diff --git a/src/gui/oscilloscopeview.h b/src/gui/oscilloscopeview.h
index b4e6a10..533c92e 100644
--- a/src/gui/oscilloscopeview.h
+++ b/src/gui/oscilloscopeview.h
@@ -33,7 +33,7 @@ class OscilloscopeView : public TQFrame
public slots:
/**
- * Sets the needRedraw flag to true, and then class tqrepaint
+ * Sets the needRedraw flag to true, and then class repaint
*/
void updateView();
void slotSetFrameRate( int fps );
diff --git a/src/gui/oscilloscopewidget.ui b/src/gui/oscilloscopewidget.ui
index 199b070..d422136 100644
--- a/src/gui/oscilloscopewidget.ui
+++ b/src/gui/oscilloscopewidget.ui
@@ -111,7 +111,7 @@
<property name="text">
<string>Zoom</string>
</property>
- <property name="tqalignment">
+ <property name="alignment">
<set>AlignCenter</set>
</property>
</widget>
@@ -164,7 +164,7 @@
<property name="text">
<string></string>
</property>
- <property name="tqalignment">
+ <property name="alignment">
<set>AlignCenter</set>
</property>
</widget>
diff --git a/src/gui/probepositioner.cpp b/src/gui/probepositioner.cpp
index 481612c..25f7119 100644
--- a/src/gui/probepositioner.cpp
+++ b/src/gui/probepositioner.cpp
@@ -41,7 +41,7 @@ ProbePositioner::~ProbePositioner()
void ProbePositioner::forceRepaint()
{
b_needRedraw = true;
- tqrepaint(false);
+ repaint(false);
}
diff --git a/src/gui/propertieslistview.cpp b/src/gui/propertieslistview.cpp
index a620621..e647997 100644
--- a/src/gui/propertieslistview.cpp
+++ b/src/gui/propertieslistview.cpp
@@ -271,7 +271,7 @@ void PropertiesListView::headerSizeChanged(int section, int /*oldSize*/, int new
// Resize the editor to the new column width
// and move it to the right place.
- TQRect rect = m_editor->tqgeometry();
+ TQRect rect = m_editor->geometry();
rect.setWidth(newSize);
rect.setX( columnWidth(0) );
m_editor->setGeometry(rect);
diff --git a/src/gui/settingsdlg.cpp b/src/gui/settingsdlg.cpp
index 72a7a07..3fd5a28 100644
--- a/src/gui/settingsdlg.cpp
+++ b/src/gui/settingsdlg.cpp
@@ -104,19 +104,19 @@ void SettingsDlg::slotUpdateRefreshRateLabel( int sliderValue )
switch(sliderValue)
{
case 0:
- m_generalOptionsWidget->refreshRateLabel->setText( i18n("Lowest (%1 FPS)").tqarg(number) );
+ m_generalOptionsWidget->refreshRateLabel->setText( i18n("Lowest (%1 FPS)").arg(number) );
break;
case 1:
- m_generalOptionsWidget->refreshRateLabel->setText( i18n("Low (%1 FPS)").tqarg(number) );
+ m_generalOptionsWidget->refreshRateLabel->setText( i18n("Low (%1 FPS)").arg(number) );
break;
case 2:
- m_generalOptionsWidget->refreshRateLabel->setText( i18n("Medium (%1 FPS)").tqarg(number) );
+ m_generalOptionsWidget->refreshRateLabel->setText( i18n("Medium (%1 FPS)").arg(number) );
break;
case 3:
- m_generalOptionsWidget->refreshRateLabel->setText( i18n("High (%1 FPS)").tqarg(number) );
+ m_generalOptionsWidget->refreshRateLabel->setText( i18n("High (%1 FPS)").arg(number) );
break;
case 4:
- m_generalOptionsWidget->refreshRateLabel->setText( i18n("Highest (%1 FPS)").tqarg(number) );
+ m_generalOptionsWidget->refreshRateLabel->setText( i18n("Highest (%1 FPS)").arg(number) );
break;
default:
m_generalOptionsWidget->refreshRateLabel->setText( i18n("Unknown value") );
@@ -141,9 +141,9 @@ void SettingsDlg::slotUpdatePicProgrammerDescription()
TQString programLocation = KStandardDirs::findExe( executable );
if ( programLocation.isNull() )
- description.prepend( i18n("<b>%1</b> cannot be found.<br>").tqarg( executable ) );
+ description.prepend( i18n("<b>%1</b> cannot be found.<br>").arg( executable ) );
else
- description.prepend( i18n("<b>%1</b> found: %2<br>").tqarg( executable ).tqarg(programLocation) );
+ description.prepend( i18n("<b>%1</b> found: %2<br>").arg( executable ).arg(programLocation) );
m_picProgrammerConfigWidget->m_pProgrammerDescription->setText( description );
m_picProgrammerConfigWidget->removeButton->setEnabled( customProgrammer );
@@ -193,7 +193,7 @@ void SettingsDlg::slotRemoveProgrammerConfig()
TQString program = combo->currentText();
- KMessageBox::ButtonCode confirm = (KMessageBox::ButtonCode)KMessageBox::warningContinueCancel( this, i18n("Remove programmer configuration \"%1\"?").tqarg(program), i18n("Remove \"%1\"").tqarg(program), i18n("Remove") );
+ KMessageBox::ButtonCode confirm = (KMessageBox::ButtonCode)KMessageBox::warningContinueCancel( this, i18n("Remove programmer configuration \"%1\"?").arg(program), i18n("Remove \"%1\"").arg(program), i18n("Remove") );
if ( confirm == KMessageBox::Cancel )
return;
diff --git a/src/item.cpp b/src/item.cpp
index 884ee17..2a59719 100644
--- a/src/item.cpp
+++ b/src/item.cpp
@@ -381,22 +381,22 @@ int Item::level() const
}
-ItemList Item::tqchildren( bool includeGrandChildren ) const
+ItemList Item::children( bool includeGrandChildren ) const
{
if (!includeGrandChildren)
- return m_tqchildren;
+ return m_children;
- ItemList tqchildren = m_tqchildren;
- ItemList::const_iterator end = m_tqchildren.end();
- for ( ItemList::const_iterator it = m_tqchildren.begin(); it != end; ++it )
+ ItemList children = m_children;
+ ItemList::const_iterator end = m_children.end();
+ for ( ItemList::const_iterator it = m_children.begin(); it != end; ++it )
{
if (!*it)
continue;
- tqchildren += (*it)->tqchildren(true);
+ children += (*it)->children(true);
}
- return tqchildren;
+ return children;
}
@@ -417,7 +417,7 @@ void Item::addChild( Item *child )
return;
}
- m_tqchildren.append(child);
+ m_children.append(child);
connect( child, TQT_SIGNAL(removed(Item* )), this, TQT_SLOT(removeChild(Item* )) );
child->setParentItem(this);
@@ -428,10 +428,10 @@ void Item::addChild( Item *child )
void Item::removeChild( Item *child )
{
- if ( !child || !m_tqchildren.contains(child) )
+ if ( !child || !m_children.contains(child) )
return;
- m_tqchildren.remove(child);
+ m_children.remove(child);
disconnect( child, TQT_SIGNAL(removed(Item* )), this, TQT_SLOT(removeChild(Item* )) );
childRemoved(child);
@@ -441,8 +441,8 @@ void Item::removeChild( Item *child )
bool Item::contains( Item *item, bool direct ) const
{
- const ItemList::const_iterator end = m_tqchildren.end();
- for ( ItemList::const_iterator it = m_tqchildren.begin(); it != end; ++it )
+ const ItemList::const_iterator end = m_children.end();
+ for ( ItemList::const_iterator it = m_children.begin(); it != end; ++it )
{
if ( (Item*)*it == item || ( !direct && (*it)->contains( item, false ) ) )
return true;
@@ -468,8 +468,8 @@ void Item::updateZ( int baseZ )
setZ(z);
- const ItemList::const_iterator end = m_tqchildren.end();
- for ( ItemList::const_iterator it = m_tqchildren.begin(); it != end; ++it )
+ const ItemList::const_iterator end = m_children.end();
+ for ( ItemList::const_iterator it = m_children.begin(); it != end; ++it )
{
if (*it)
(*it)->updateZ(baseZ+1);
diff --git a/src/item.h b/src/item.h
index af438f7..56cf426 100644
--- a/src/item.h
+++ b/src/item.h
@@ -130,7 +130,7 @@ public:
bool isRaised() const { return m_bIsRaised; }
/**
* Sets this item to the given baseZ level, and calls this function for the
- * tqchildren with baseZ incremented by one. Reinherit this function to set
+ * children with baseZ incremented by one. Reinherit this function to set
* the Z of attached stuff (such as nodes).
*/
virtual void updateZ( int baseZ );
@@ -143,12 +143,12 @@ public:
*/
void addChild( Item *child );
/**
- * Returns the list of tqchildren.
+ * Returns the list of children.
* @param if includeGrandChildren is true then this list will also contain
- * the tqchildren's tqchildren, and so on recursively, instead of just the
- * immediate tqchildren.
+ * the children's children, and so on recursively, instead of just the
+ * immediate children.
*/
- ItemList tqchildren( bool includeGrandChildren = false ) const;
+ ItemList children( bool includeGrandChildren = false ) const;
/**
* Returns whether we have the given child as either a direct child, or as
* either a direct or indirect child
@@ -259,17 +259,17 @@ protected slots:
protected:
/**
- * Reinherit this function if you want to do anything with tqchildren. Called
+ * Reinherit this function if you want to do anything with children. Called
* after the parent is changed, with the old parent and the new parent.
*/
virtual void reparented( Item */*oldParent*/, Item */*newParent*/ ) {};
/**
- * Reinherit this function if you want to do anything with tqchildren. Called
+ * Reinherit this function if you want to do anything with children. Called
* after a child has been added.
*/
virtual void childAdded( Item * ) {};
/**
- * Reinherit this function if you want to do anything with tqchildren. Called
+ * Reinherit this function if you want to do anything with children. Called
* after a child has been removed.
*/
virtual void childRemoved( Item * ) {};
@@ -290,7 +290,7 @@ protected:
TQString m_name, m_desc; // Name and description
TQString m_type;
GuardedItem p_parentItem; // If attached to a parent item
- ItemList m_tqchildren;
+ ItemList m_children;
TQGuardedPtr<ItemDocument> p_itemDocument;
TQPointArray m_itemPoints; // The unorientated and unsized item points
diff --git a/src/itemdocument.cpp b/src/itemdocument.cpp
index 7aded9b..ec20d43 100644
--- a/src/itemdocument.cpp
+++ b/src/itemdocument.cpp
@@ -820,7 +820,7 @@ void ItemDocument::exportToImage()
if ( TQFile::exists( url.path() ) )
{
- int query = KMessageBox::warningYesNo( p_ktechlab, i18n( "A file named \"%1\" already exists. " "Are you sure you want to overwrite it?" ).tqarg( url.fileName() ), i18n( "Overwrite File?" ), i18n( "Overwrite" ), KStdGuiItem::cancel() );
+ int query = KMessageBox::warningYesNo( p_ktechlab, i18n( "A file named \"%1\" already exists. " "Are you sure you want to overwrite it?" ).arg( url.fileName() ), i18n( "Overwrite File?" ), i18n( "Overwrite" ), KStdGuiItem::cancel() );
if ( query == KMessageBox::No ) return;
}
@@ -924,7 +924,7 @@ void ItemDocument::exportToImage()
saveResult = dynamic_cast<TQPixmap*>(outputImage)->save( url.path(), type );
}
- //if(saveResult == true) KMessageBox::information( this, i18n("Sucessfully exported to \"%1\"").tqarg( url.filename() ), i18n("Image Export") );
+ //if(saveResult == true) KMessageBox::information( this, i18n("Sucessfully exported to \"%1\"").arg( url.filename() ), i18n("Image Export") );
//else KMessageBox::information( this, i18n("Export failed"), i18n("Image Export") );
if ( type == "SVG" )
@@ -1170,7 +1170,7 @@ void CanvasTip::display( const TQPoint &pos )
{
TQString text;
for ( unsigned i = 0; i < num; i++ )
- text += TQString(" %1: %2\n").tqarg( TQString::number(i) ).tqarg( displayText(i) );
+ text += TQString(" %1: %2\n").arg( TQString::number(i) ).arg( displayText(i) );
setText(text);
}
}
@@ -1182,10 +1182,10 @@ TQString CanvasTip::displayText( unsigned num ) const
return TQString();
return TQString(" %1%2V %3%4A ")
- .tqarg( TQString::number( m_v[num] / CNItem::getMultiplier(m_v[num]), 'g', 3 ) )
- .tqarg( CNItem::getNumberMag( m_v[num] ) )
- .tqarg( TQString::number( m_i[num] / CNItem::getMultiplier(m_i[num]), 'g', 3 ) )
- .tqarg( CNItem::getNumberMag( m_i[num] ) );
+ .arg( TQString::number( m_v[num] / CNItem::getMultiplier(m_v[num]), 'g', 3 ) )
+ .arg( CNItem::getNumberMag( m_v[num] ) )
+ .arg( TQString::number( m_i[num] / CNItem::getMultiplier(m_i[num]), 'g', 3 ) )
+ .arg( CNItem::getNumberMag( m_i[num] ) );
}
diff --git a/src/itemdocumentdata.cpp b/src/itemdocumentdata.cpp
index f9085b8..61271f0 100644
--- a/src/itemdocumentdata.cpp
+++ b/src/itemdocumentdata.cpp
@@ -110,7 +110,7 @@ bool ItemDocumentData::loadData( const KURL &url )
TQFile file(target);
if ( !file.open( IO_ReadOnly ) )
{
- KMessageBox::sorry( 0l, i18n("Could not open %1 for reading").tqarg(target) );
+ KMessageBox::sorry( 0l, i18n("Could not open %1 for reading").arg(target) );
return false;
}
@@ -132,7 +132,7 @@ bool ItemDocumentData::fromXML( const TQString &xml )
TQString errorMessage;
if ( !doc.setContent( xml, &errorMessage ) )
{
- KMessageBox::sorry( 0l, i18n("Couldn't parse xml:\n%1").tqarg(errorMessage) );
+ KMessageBox::sorry( 0l, i18n("Couldn't parse xml:\n%1").arg(errorMessage) );
return false;
}
@@ -180,7 +180,7 @@ bool ItemDocumentData::saveData( const KURL &url )
TQFile file( url.path() );
if ( !file.open(IO_WriteOnly) )
{
- KMessageBox::sorry( 0l, i18n("Could not open '%1' for writing. Check that you have write permissions").tqarg(url.path()), i18n("Saving File") );
+ KMessageBox::sorry( 0l, i18n("Could not open '%1' for writing. Check that you have write permissions").arg(url.path()), i18n("Saving File") );
return false;
}
@@ -1001,7 +1001,7 @@ void ItemDocumentData::mergeWithDocument( ItemDocument *itemDocument, bool selec
if (item)
{
//HACK We move the item now before restoreFromItemData is called later, in case it is to be parented
- //(as we don't want to move tqchildren)...
+ //(as we don't want to move children)...
item->move( it.data().x, it.data().y );
}
}
diff --git a/src/itemgroup.cpp b/src/itemgroup.cpp
index ee6816c..c1ab4da 100644
--- a/src/itemgroup.cpp
+++ b/src/itemgroup.cpp
@@ -52,22 +52,22 @@ ItemList ItemGroup::items( bool excludeParentedItems ) const
do
{
oldSize = items.size();
- ItemList tqchildren;
+ ItemList children;
ItemList::iterator end = parents.end();
for ( ItemList::iterator it = parents.begin(); it != end; ++it )
- tqchildren += (*it)->tqchildren();
+ children += (*it)->children();
- end = tqchildren.end();
- for ( ItemList::iterator it = tqchildren.begin(); it != end; ++it )
+ end = children.end();
+ for ( ItemList::iterator it = children.begin(); it != end; ++it )
{
- if ( tqchildren.contains(*it) > 1 )
+ if ( children.contains(*it) > 1 )
*it = 0l;
}
- tqchildren.remove((Item*)0l);
+ children.remove((Item*)0l);
- items += tqchildren;
- parents = tqchildren;
+ items += children;
+ parents = children;
}
while ( oldSize != items.size() );
diff --git a/src/itemlibrary.cpp b/src/itemlibrary.cpp
index 4d955d2..720c5c7 100644
--- a/src/itemlibrary.cpp
+++ b/src/itemlibrary.cpp
@@ -381,7 +381,7 @@ TQImage ItemLibrary::itemImage( Item *item, const uint maxSize )
p.setPen( item->pen() );
p.setBrush( item->brush() );
- // Now draw the tqshape :-)
+ // Now draw the shape :-)
const bool sel = item->isSelected();
if (sel)
{
diff --git a/src/katemdi.cpp b/src/katemdi.cpp
index 5378396..5f62d95 100644
--- a/src/katemdi.cpp
+++ b/src/katemdi.cpp
@@ -478,7 +478,7 @@ void Sidebar::restoreSession (KConfig *config)
{
ToolView *tv = m_toolviews[firstWrong];
- unsigned int pos = config->readUnsignedNumEntry (TQString ("Kate-MDI-ToolView-%1-Sidebar-Position").tqarg(tv->id), firstWrong);
+ unsigned int pos = config->readUnsignedNumEntry (TQString ("Kate-MDI-ToolView-%1-Sidebar-Position").arg(tv->id), firstWrong);
if (pos != firstWrong)
break;
@@ -493,7 +493,7 @@ void Sidebar::restoreSession (KConfig *config)
{
TmpToolViewSorter s;
s.tv = m_toolviews[i];
- s.pos = config->readUnsignedNumEntry (TQString ("Kate-MDI-ToolView-%1-Sidebar-Position").tqarg(m_toolviews[i]->id), i);
+ s.pos = config->readUnsignedNumEntry (TQString ("Kate-MDI-ToolView-%1-Sidebar-Position").arg(m_toolviews[i]->id), i);
toSort.push_back (s);
}
@@ -536,7 +536,7 @@ void Sidebar::restoreSession (KConfig *config)
updateLastSize ();
// restore the own splitter sizes
- TQValueList<int> s = config->readIntListEntry (TQString ("Kate-MDI-Sidebar-%1-Splitter").tqarg(sidebarPosition()));
+ TQValueList<int> s = config->readIntListEntry (TQString ("Kate-MDI-Sidebar-%1-Splitter").arg(sidebarPosition()));
m_ownSplit->setSizes (s);
// show only correct toolviews, remember persistent values ;)
@@ -545,8 +545,8 @@ void Sidebar::restoreSession (KConfig *config)
{
ToolView *tv = m_toolviews[i];
- tv->persistent = config->readBoolEntry (TQString ("Kate-MDI-ToolView-%1-Persistent").tqarg(tv->id), false);
- tv->setVisible (config->readBoolEntry (TQString ("Kate-MDI-ToolView-%1-Visible").tqarg(tv->id), false));
+ tv->persistent = config->readBoolEntry (TQString ("Kate-MDI-ToolView-%1-Persistent").arg(tv->id), false);
+ tv->setVisible (config->readBoolEntry (TQString ("Kate-MDI-ToolView-%1-Visible").arg(tv->id), false));
if (!anyVis)
anyVis = tv->visible();
@@ -569,17 +569,17 @@ void Sidebar::saveSession (KConfig *config)
{
// store the own splitter sizes
TQValueList<int> s = m_ownSplit->sizes();
- config->writeEntry (TQString ("Kate-MDI-Sidebar-%1-Splitter").tqarg(sidebarPosition()), s);
+ config->writeEntry (TQString ("Kate-MDI-Sidebar-%1-Splitter").arg(sidebarPosition()), s);
// store the data about all toolviews in this sidebar ;)
for ( unsigned int i=0; i < m_toolviews.size(); ++i )
{
ToolView *tv = m_toolviews[i];
- config->writeEntry (TQString ("Kate-MDI-ToolView-%1-Position").tqarg(tv->id), tv->sidebar()->sidebarPosition());
- config->writeEntry (TQString ("Kate-MDI-ToolView-%1-Sidebar-Position").tqarg(tv->id), i);
- config->writeEntry (TQString ("Kate-MDI-ToolView-%1-Visible").tqarg(tv->id), tv->visible());
- config->writeEntry (TQString ("Kate-MDI-ToolView-%1-Persistent").tqarg(tv->id), tv->persistent);
+ config->writeEntry (TQString ("Kate-MDI-ToolView-%1-Position").arg(tv->id), tv->sidebar()->sidebarPosition());
+ config->writeEntry (TQString ("Kate-MDI-ToolView-%1-Sidebar-Position").arg(tv->id), i);
+ config->writeEntry (TQString ("Kate-MDI-ToolView-%1-Visible").arg(tv->id), tv->visible());
+ config->writeEntry (TQString ("Kate-MDI-ToolView-%1-Persistent").arg(tv->id), tv->persistent);
}
}
@@ -651,7 +651,7 @@ ToolView *MainWindow::createToolView (const TQString &identifier, KMultiTabBar::
if (m_restoreConfig && m_restoreConfig->hasGroup (m_restoreGroup))
{
m_restoreConfig->setGroup (m_restoreGroup);
- pos = (KMultiTabBar::KMultiTabBarPosition) m_restoreConfig->readNumEntry (TQString ("Kate-MDI-ToolView-%1-Position").tqarg(identifier), pos);
+ pos = (KMultiTabBar::KMultiTabBarPosition) m_restoreConfig->readNumEntry (TQString ("Kate-MDI-ToolView-%1-Position").arg(identifier), pos);
}
ToolView *v = m_sidebars[pos]->addWidget (icon, text, 0);
@@ -710,7 +710,7 @@ bool MainWindow::moveToolView (ToolView *widget, KMultiTabBar::KMultiTabBarPosit
if (m_restoreConfig && m_restoreConfig->hasGroup (m_restoreGroup))
{
m_restoreConfig->setGroup (m_restoreGroup);
- pos = (KMultiTabBar::KMultiTabBarPosition) m_restoreConfig->readNumEntry (TQString ("Kate-MDI-ToolView-%1-Position").tqarg(widget->id), pos);
+ pos = (KMultiTabBar::KMultiTabBarPosition) m_restoreConfig->readNumEntry (TQString ("Kate-MDI-ToolView-%1-Position").arg(widget->id), pos);
}
m_sidebars[pos]->addWidget (widget->icon, widget->text, widget);
@@ -803,7 +803,7 @@ void MainWindow::finishRestore ()
m_restoreConfig->setGroup (m_restoreGroup);
for ( unsigned int i=0; i < m_toolviews.size(); ++i )
{
- KMultiTabBar::KMultiTabBarPosition newPos = (KMultiTabBar::KMultiTabBarPosition) m_restoreConfig->readNumEntry (TQString ("Kate-MDI-ToolView-%1-Position").tqarg(m_toolviews[i]->id), m_toolviews[i]->sidebar()->sidebarPosition());
+ KMultiTabBar::KMultiTabBarPosition newPos = (KMultiTabBar::KMultiTabBarPosition) m_restoreConfig->readNumEntry (TQString ("Kate-MDI-ToolView-%1-Position").arg(m_toolviews[i]->id), m_toolviews[i]->sidebar()->sidebarPosition());
if (m_toolviews[i]->sidebar()->sidebarPosition() != newPos)
{
diff --git a/src/ktechlab.cpp b/src/ktechlab.cpp
index ecbb255..d73d77f 100644
--- a/src/ktechlab.cpp
+++ b/src/ktechlab.cpp
@@ -293,9 +293,9 @@ void KTechlab::overlayToolBarScreenshot()
// 128 is a sanity check (widget can do strange things when being destroyed)
if ( toolsWidget && toolsWidget->height() <= 128 )
- grabRect |= toolsWidget->tqgeometry();
+ grabRect |= toolsWidget->geometry();
if ( debugWidget && debugWidget->height() <= 128 )
- grabRect |= debugWidget->tqgeometry();
+ grabRect |= debugWidget->geometry();
if ( !grabRect.isValid() )
return;
@@ -647,8 +647,8 @@ void KTechlab::saveProperties( KConfig *conf )
conf->setGroup("KateMDI");
int scnum = TQApplication::desktop()->screenNumber(parentWidget());
TQRect desk = TQApplication::desktop()->screenGeometry(scnum);
- conf->deleteEntry( TQString::fromLatin1("Width %1").tqarg(desk.width()) );
- conf->deleteEntry( TQString::fromLatin1("Height %1").tqarg(desk.height()) );
+ conf->deleteEntry( TQString::fromLatin1("Width %1").arg(desk.width()) );
+ conf->deleteEntry( TQString::fromLatin1("Height %1").arg(desk.height()) );
conf->sync();
}
diff --git a/src/languages/flowcode.cpp b/src/languages/flowcode.cpp
index 5356eab..fe575f9 100644
--- a/src/languages/flowcode.cpp
+++ b/src/languages/flowcode.cpp
@@ -173,7 +173,7 @@ TQString FlowCode::generateMicrobe( const ItemList &itemList, MicroSettings *set
continue;
if ( !startPart->outputPart( nodeMapIt.key() ) )
- outputWarning( i18n("Warning: Floating connection for %1").tqarg( startPart->id() ) );
+ outputWarning( i18n("Warning: Floating connection for %1").arg( startPart->id() ) );
}
FlowContainer * fc = dynamic_cast<FlowContainer*>((Item*)*it);
@@ -259,7 +259,7 @@ TQString FlowCode::generateMicrobe( const ItemList &itemList, MicroSettings *set
if ( type.isEmpty() )
continue;
- addCode( TQString("%1 %2 %3").tqarg( type ).tqarg( it.key() ).tqarg( it.data().pins().join(" ") ) );
+ addCode( TQString("%1 %2 %3").arg( type ).arg( it.key() ).arg( it.data().pins().join(" ") ) );
}
}
diff --git a/src/languages/picprogrammer.cpp b/src/languages/picprogrammer.cpp
index 5ef37dd..837a937 100644
--- a/src/languages/picprogrammer.cpp
+++ b/src/languages/picprogrammer.cpp
@@ -63,7 +63,7 @@ void PicProgrammerSettings::initStaticConfigs()
m_bDoneStaticConfigsInit = true;
ProgrammerConfig config;
- config.description = i18n("Supported programmers: %1").tqarg("JuPic, PICStart Plus, Warp-13");
+ config.description = i18n("Supported programmers: %1").arg("JuPic, PICStart Plus, Warp-13");
config.description += i18n("<br>Interface: Serial Port");
config.initCommand = "";
config.readCommand = "picp %port %device -rp %file";
@@ -75,7 +75,7 @@ void PicProgrammerSettings::initStaticConfigs()
m_staticConfigs[ "PICP" ] = config;
- config.description = i18n("Supported programmers: %1").tqarg("Epic Plus");
+ config.description = i18n("Supported programmers: %1").arg("Epic Plus");
config.description += i18n("<br>Interface: Parallel Port");
config.initCommand = "odyssey init";
config.readCommand = "odyssey %device read %file";
@@ -87,7 +87,7 @@ void PicProgrammerSettings::initStaticConfigs()
m_staticConfigs[ "Odyssey" ] = config;
- config.description = i18n("Supported programmers: %1").tqarg("JDM PIC-Programmer 2, PIC-PG2C");
+ config.description = i18n("Supported programmers: %1").arg("JDM PIC-Programmer 2, PIC-PG2C");
config.description += i18n("<br>Interface: Serial Port");
config.initCommand = "";
config.readCommand = "picprog --output %file --pic %port";
@@ -98,7 +98,7 @@ void PicProgrammerSettings::initStaticConfigs()
m_staticConfigs[ "PICProg" ] = config;
- config.description = i18n("Supported programmers: %1").tqarg("Epic Plus");
+ config.description = i18n("Supported programmers: %1").arg("Epic Plus");
config.description += i18n("<br>Interface: Parallel Port");
config.initCommand = "";
config.readCommand = "dump84 --dump-all --output=%file";
@@ -109,7 +109,7 @@ void PicProgrammerSettings::initStaticConfigs()
m_staticConfigs[ "prog84" ] = config;
- config.description = i18n("Supported programmers: %1").tqarg("Kit 149, Kit 150");
+ config.description = i18n("Supported programmers: %1").arg("Kit 149, Kit 150");
config.description += i18n("<br>Interface: USB Port");
config.initCommand = "";
config.readCommand = "pp -d %device -r %file";
@@ -120,7 +120,7 @@ void PicProgrammerSettings::initStaticConfigs()
m_staticConfigs[ "PP" ] = config;
- config.description = i18n("Supported programmers: %1").tqarg("Wisp628");
+ config.description = i18n("Supported programmers: %1").arg("Wisp628");
config.description += i18n("<br>Interface: Serial Port");
config.initCommand = "";
config.readCommand = "xwisp ID %device PORT %device DUMP";
@@ -132,7 +132,7 @@ void PicProgrammerSettings::initStaticConfigs()
#if 0
- config.description = i18n("Supported programmers: %1").tqarg("Epic Plus, JDM PIC-Programmer 2, PICCOLO, PICCOLO Grande, Trivial HVP Programmer");
+ config.description = i18n("Supported programmers: %1").arg("Epic Plus, JDM PIC-Programmer 2, PICCOLO, PICCOLO Grande, Trivial HVP Programmer");
config.description += i18n("<br>Interface: Serial Port and Parallel Port");
config.initCommand = "";
config.readCommand = "";
@@ -145,7 +145,7 @@ void PicProgrammerSettings::initStaticConfigs()
config.executable = "";
- config.description = i18n("Supported programmers: %1").tqarg("Trivial LVP programmer, Trivial HVP Programmer");
+ config.description = i18n("Supported programmers: %1").arg("Trivial LVP programmer, Trivial HVP Programmer");
config.description += i18n("<br>Interface: Parallel Port");
config.initCommand = "";
config.readCommand = "";
@@ -156,7 +156,7 @@ void PicProgrammerSettings::initStaticConfigs()
m_staticConfigs[ "PicPrg2" ] = config;
- config.description = i18n("Supported programmers: %1").tqarg("El Cheapo");
+ config.description = i18n("Supported programmers: %1").arg("El Cheapo");
config.description += i18n("<br>Interface: Parallel Port");
config.initCommand = "";
config.readCommand = "";
@@ -167,7 +167,7 @@ void PicProgrammerSettings::initStaticConfigs()
m_staticConfigs[ "PP06" ] = config;
- config.description = i18n("Supported programmers: %1").tqarg("NOPPP");
+ config.description = i18n("Supported programmers: %1").arg("NOPPP");
config.description += i18n("<br>Interface: Parallel Port");
config.initCommand = "";
config.readCommand = "";
@@ -178,7 +178,7 @@ void PicProgrammerSettings::initStaticConfigs()
m_staticConfigs[ "NOPPP" ] = config;
- config.description = i18n("Supported programmers: %1").tqarg("SNOPPP");
+ config.description = i18n("Supported programmers: %1").arg("SNOPPP");
config.description += i18n("<br>Interface: Parallel Port");
config.initCommand = "";
config.readCommand = "";
@@ -232,7 +232,7 @@ void PicProgrammerSettings::save( KConfig * config )
ProgrammerConfigMap::iterator end = m_customConfigs.end();
for ( ProgrammerConfigMap::iterator it = m_customConfigs.begin(); it != end; ++it )
{
- config->setGroup( TQString("CustomProgrammer_%1").tqarg(at++) );
+ config->setGroup( TQString("CustomProgrammer_%1").arg(at++) );
config->writeEntry( "Name", it.key() );
config->writeEntry( "InitCommand", it.data().initCommand );
diff --git a/src/languages/processchain.cpp b/src/languages/processchain.cpp
index 6f5c95a..00edbb8 100644
--- a/src/languages/processchain.cpp
+++ b/src/languages/processchain.cpp
@@ -56,7 +56,7 @@ ProcessChain::ProcessChain( ProcessOptions options, KTechlab * ktechlab, const c
else
target = options.targetFile();
- LanguageManager::self()->logView()->addOutput( i18n("Building: %1").tqarg( target ), LogView::ot_important );
+ LanguageManager::self()->logView()->addOutput( i18n("Building: %1").arg( target ), LogView::ot_important );
TQTimer::singleShot( 0, this, TQT_SLOT(compile()) );
}
diff --git a/src/languages/sdcc.cpp b/src/languages/sdcc.cpp
index ea1845d..96cf54c 100644
--- a/src/languages/sdcc.cpp
+++ b/src/languages/sdcc.cpp
@@ -40,7 +40,7 @@ void SDCC::processInput( ProcessOptions options )
MicroInfo * info = MicroLibrary::self()->microInfoWithID( options.m_picID );
if (!info)
{
- outputError( i18n("Could not find PIC with ID \"%1\".").tqarg(options.m_picID) );
+ outputError( i18n("Could not find PIC with ID \"%1\".").arg(options.m_picID) );
return;
}
@@ -50,7 +50,7 @@ void SDCC::processInput( ProcessOptions options )
//BEGIN Pass custom sdcc options
-#define ARG(text,option) if ( KTLConfig::text() ) *m_languageProcess << ( TQString("--%1").tqarg(option) );
+#define ARG(text,option) if ( KTLConfig::text() ) *m_languageProcess << ( TQString("--%1").arg(option) );
// General
ARG( sDCC_nostdlib, "nostdlib" )
ARG( sDCC_nostdinc, "nostdinc" )
diff --git a/src/mechanics/mechanicsgroup.cpp b/src/mechanics/mechanicsgroup.cpp
index 900eb92..2c577c8 100644
--- a/src/mechanics/mechanicsgroup.cpp
+++ b/src/mechanics/mechanicsgroup.cpp
@@ -71,9 +71,9 @@ void MechanicsGroup::removeChildren( Item *item )
if (!item)
return;
- const ItemList tqchildren = item->tqchildren();
- const ItemList::const_iterator end = tqchildren.end();
- for ( ItemList::const_iterator it = tqchildren.begin(); it != end; ++it )
+ const ItemList children = item->children();
+ const ItemList::const_iterator end = children.end();
+ for ( ItemList::const_iterator it = children.begin(); it != end; ++it )
{
removeChildren(*it);
removeItem(*it);
diff --git a/src/mechanics/mechanicsgroup.h b/src/mechanics/mechanicsgroup.h
index 0908d66..1ea2dc5 100644
--- a/src/mechanics/mechanicsgroup.h
+++ b/src/mechanics/mechanicsgroup.h
@@ -42,7 +42,7 @@ public:
*/
void setRaised( bool isRaised );
/**
- * Removes all the tqchildren of the given item from the group
+ * Removes all the children of the given item from the group
*/
void removeChildren( Item *item );
bool addItem( Item *item );
diff --git a/src/mechanics/mechanicsitem.cpp b/src/mechanics/mechanicsitem.cpp
index 96c4adf..81340b4 100644
--- a/src/mechanics/mechanicsitem.cpp
+++ b/src/mechanics/mechanicsitem.cpp
@@ -206,8 +206,8 @@ void MechanicsItem::updateMechanicsInfoCombined()
double mass_x = 0.;
double mass_y = 0.;
- const ItemList::const_iterator end = m_tqchildren.end();
- for ( ItemList::const_iterator it = m_tqchildren.begin(); it != end; ++it )
+ const ItemList::const_iterator end = m_children.end();
+ for ( ItemList::const_iterator it = m_children.begin(); it != end; ++it )
{
MechanicsItem *child = dynamic_cast<MechanicsItem*>((Item*)*it);
if (child)
diff --git a/src/mechanics/mechanicsitem.h b/src/mechanics/mechanicsitem.h
index 3c8f7a1..712ff3c 100644
--- a/src/mechanics/mechanicsitem.h
+++ b/src/mechanics/mechanicsitem.h
@@ -158,12 +158,12 @@ public:
PositionInfo relativePosition() const { return m_relativePosition; }
/**
* Returns the mechanics info for this item (so not taking into account that
- * of attached tqchildren)
+ * of attached children)
*/
MechanicsInfo *mechanicsInfo() { return &m_mechanicsInfo; }
/**
* Returns the combined mechanics info for this item (which takes into
- * account that of attached tqchildren).
+ * account that of attached children).
*/
CombinedMechanicsInfo *mechanicsInfoCombined() { return &m_mechanicsInfoCombined; }
/**
diff --git a/src/node.h b/src/node.h
index f5e5f0b..271fdf1 100644
--- a/src/node.h
+++ b/src/node.h
@@ -177,7 +177,7 @@ public:
void removeNullConnectors();
/**
- * Draw tqshape. Note that this has to remain public.
+ * Draw shape. Note that this has to remain public.
*/
virtual void drawShape( TQPainter &p ) = 0;
diff --git a/src/recentfilesaction.cpp b/src/recentfilesaction.cpp
index deba448..22f0d24 100644
--- a/src/recentfilesaction.cpp
+++ b/src/recentfilesaction.cpp
@@ -86,7 +86,7 @@ void RecentFilesAction::loadEntries()
// read file list
for( unsigned int i = 1 ; i <= m_maxItems ; i++ )
{
- key = TQString( "File%1" ).tqarg( i );
+ key = TQString( "File%1" ).arg( i );
value = config->readPathEntry( key );
if (!value.isNull())
@@ -116,7 +116,7 @@ void RecentFilesAction::saveEntries()
// write file list
for( unsigned int i = 1 ; i <= lst.count() ; i++ )
{
- key = TQString( "File%1" ).tqarg( i );
+ key = TQString( "File%1" ).arg( i );
value = lst[ i - 1 ];
config->writePathEntry( key, value );
}
diff --git a/src/textdocument.cpp b/src/textdocument.cpp
index 77cfb30..53d98e4 100644
--- a/src/textdocument.cpp
+++ b/src/textdocument.cpp
@@ -603,9 +603,9 @@ void TextDocument::slotUpdateMarksInfo()
{
if ( mark->type & Bookmark )
{
- KAction * a = new KAction( i18n("%1 - %2").tqarg( TQString::number( mark->line+1 ) ).tqarg( m_doc->textLine(mark->line) ),
+ KAction * a = new KAction( i18n("%1 - %2").arg( TQString::number( mark->line+1 ) ).arg( m_doc->textLine(mark->line) ),
0, this, TQT_SLOT(slotBookmarkRequested()), this,
- TQString("bookmark_%1").tqarg(TQString::number(mark->line).ascii()) );
+ TQString("bookmark_%1").arg(TQString::number(mark->line).ascii()) );
m_bookmarkActions.append(a);
}
}
diff --git a/src/textview.cpp b/src/textview.cpp
index 0d7f639..e5c4648 100644
--- a/src/textview.cpp
+++ b/src/textview.cpp
@@ -262,7 +262,7 @@ void TextView::slotCursorPositionChanged()
uint line, column;
m_view->cursorPosition( &line, &column );
- m_statusBar->changeItem( i18n(" Line: %1 Col: %2 ").tqarg(TQString::number(line+1)).tqarg(TQString::number(column+1)), ViewStatusBar::LineCol );
+ m_statusBar->changeItem( i18n(" Line: %1 Col: %2 ").arg(TQString::number(line+1)).arg(TQString::number(column+1)), ViewStatusBar::LineCol );
slotUpdateMarksInfo();
}
diff --git a/src/variablelabel.cpp b/src/variablelabel.cpp
index 10e0a2a..0d0472c 100644
--- a/src/variablelabel.cpp
+++ b/src/variablelabel.cpp
@@ -77,7 +77,7 @@ void VariableLabel::setValue( unsigned value )
void VariableLabel::updateText()
{
if ( m_pRegisterInfo )
- setText( TQString("%1 = %2").tqarg( m_registerName ).tqarg( SymbolViewer::self()->toDisplayString( m_pRegisterInfo->value() ) ) );
+ setText( TQString("%1 = %2").arg( m_registerName ).arg( SymbolViewer::self()->toDisplayString( m_pRegisterInfo->value() ) ) );
else if ( m_value != -1 )
setText( TQString::number( m_value ) );
diff --git a/src/viewcontainer.h b/src/viewcontainer.h
index 50458b6..1d09db1 100644
--- a/src/viewcontainer.h
+++ b/src/viewcontainer.h
@@ -82,7 +82,7 @@ public:
void restoreState( KConfig *config, int id, const TQString &groupName );
/**
* Returns true if this ViewArea can save useful information as to its state
- * (i.e. it's tqchildren can save useful information about their state, or has
+ * (i.e. it's children can save useful information about their state, or has
* a view with a url in it)
*/
bool canSaveUsefulStateInfo() const;
@@ -218,7 +218,7 @@ public:
int uniqueNewId();
/**
* Returns true if this ViewArea can save useful information as to its state
- * (i.e. it's tqchildren can save useful information about their state, or has
+ * (i.e. it's children can save useful information about their state, or has
* a view with a url in it)
*/
bool canSaveUsefulStateInfo() const;
diff --git a/src/projectmanager.cpp b/src/projectmanager.cpp
index 3a6565c..2bdca82 100644
--- a/src/projectmanager.cpp
+++ b/src/projectmanager.cpp
@@ -192,11 +192,11 @@ ProjectItem::ProjectItem( ProjectItem * parent, Type type, ProjectManager * proj
ProjectItem::~ProjectItem()
{
- m_tqchildren.remove( (ProjectItem*)0l );
- ProjectItemList::iterator end = m_tqchildren.end();
- for ( ProjectItemList::iterator it = m_tqchildren.begin(); it != end; ++it )
+ m_children.remove( (ProjectItem*)0l );
+ ProjectItemList::iterator end = m_children.end();
+ for ( ProjectItemList::iterator it = m_children.begin(); it != end; ++it )
(*it)->deleteLater();
- m_tqchildren.clear();
+ m_children.clear();
delete m_pILVItem;
m_pILVItem = 0l;
@@ -254,10 +254,10 @@ void ProjectItem::updateILVItemPixmap()
void ProjectItem::addChild( ProjectItem * child )
{
- if ( !child || m_tqchildren.contains(child) )
+ if ( !child || m_children.contains(child) )
return;
- m_tqchildren << child;
+ m_children << child;
child->setILVItem( m_pILVItem ?
new ILVItem( m_pILVItem, child->name() ) :
@@ -283,9 +283,9 @@ void ProjectItem::updateControlChildMicroIDs()
break;
}
- m_tqchildren.remove( (ProjectItem*)0l );
- ProjectItemList::iterator end = m_tqchildren.end();
- for ( ProjectItemList::iterator it = m_tqchildren.begin(); it != end; ++it )
+ m_children.remove( (ProjectItem*)0l );
+ ProjectItemList::iterator end = m_children.end();
+ for ( ProjectItemList::iterator it = m_children.begin(); it != end; ++it )
(*it)->setUseParentMicroID( control );
}
@@ -420,7 +420,7 @@ bool ProjectItem::build( ProcessOptionsList * pol )
if ( outputURL().isEmpty() )
{
- KMessageBox::sorry( 0l, i18n("Don't know how to build \"%1\" (output url is empty).").tqarg(name()) );
+ KMessageBox::sorry( 0l, i18n("Don't know how to build \"%1\" (output url is empty).").arg(name()) );
return false;
}
@@ -431,7 +431,7 @@ bool ProjectItem::build( ProcessOptionsList * pol )
ProjectItem * lib = projectInfo->findItem( projectInfo->directory() + *it );
if ( !lib )
{
- KMessageBox::sorry( 0l, i18n("Don't know how to build \"%1\" (library does not exist in project).").tqarg(*it) );
+ KMessageBox::sorry( 0l, i18n("Don't know how to build \"%1\" (library does not exist in project).").arg(*it) );
return false;
}
@@ -440,10 +440,10 @@ bool ProjectItem::build( ProcessOptionsList * pol )
}
- // Build all tqchildren
- m_tqchildren.remove( (ProjectItem*)0l );
- ProjectItemList::iterator cend = m_tqchildren.end();
- for ( ProjectItemList::iterator it = m_tqchildren.begin(); it != cend; ++it )
+ // Build all children
+ m_children.remove( (ProjectItem*)0l );
+ ProjectItemList::iterator cend = m_children.end();
+ for ( ProjectItemList::iterator it = m_children.begin(); it != cend; ++it )
{
if ( ! (*it)->build(pol) )
return false;
@@ -461,7 +461,7 @@ bool ProjectItem::build( ProcessOptionsList * pol )
switch ( outputType() )
{
case UnknownOutput:
- KMessageBox::sorry( 0l, i18n("Don't know how to build \"%1\" (unknown output type).").tqarg(name()) );
+ KMessageBox::sorry( 0l, i18n("Don't know how to build \"%1\" (unknown output type).").arg(name()) );
return false;
case ProgramOutput:
@@ -494,9 +494,9 @@ bool ProjectItem::build( ProcessOptionsList * pol )
TQStringList inputFiles;
// Link child objects
- m_tqchildren.remove( (ProjectItem*)0l );
- ProjectItemList::iterator cend = m_tqchildren.end();
- for ( ProjectItemList::iterator it = m_tqchildren.begin(); it != cend; ++it )
+ m_children.remove( (ProjectItem*)0l );
+ ProjectItemList::iterator cend = m_children.end();
+ for ( ProjectItemList::iterator it = m_children.begin(); it != cend; ++it )
inputFiles << (*it)->outputURL().path();
po.setInputFiles(inputFiles);
@@ -565,8 +565,8 @@ TQDomElement ProjectItem::toDomElement( TQDomDocument & doc, const KURL & baseUR
node.appendChild( ProcessingOptions::toDomElement( doc, baseURL ) );
- ProjectItemList::const_iterator end = m_tqchildren.end();
- for ( ProjectItemList::const_iterator it = m_tqchildren.begin(); it != end; ++it )
+ ProjectItemList::const_iterator end = m_children.end();
+ for ( ProjectItemList::const_iterator it = m_children.begin(); it != end; ++it )
{
if (*it)
node.appendChild( (*it)->toDomElement( doc, baseURL ) );
@@ -580,8 +580,8 @@ KURL::List ProjectItem::childOutputURLs( unsigned types, unsigned outputTypes )
{
KURL::List urls;
- ProjectItemList::const_iterator end = m_tqchildren.end();
- for ( ProjectItemList::const_iterator it = m_tqchildren.begin(); it != end; ++it )
+ ProjectItemList::const_iterator end = m_children.end();
+ for ( ProjectItemList::const_iterator it = m_children.begin(); it != end; ++it )
{
if (!*it)
continue;
@@ -601,8 +601,8 @@ ProjectItem * ProjectItem::findItem( const KURL & url )
if ( this->url() == url )
return this;
- ProjectItemList::const_iterator end = m_tqchildren.end();
- for ( ProjectItemList::const_iterator it = m_tqchildren.begin(); it != end; ++it )
+ ProjectItemList::const_iterator end = m_children.end();
+ for ( ProjectItemList::const_iterator it = m_children.begin(); it != end; ++it )
{
if (!*it)
continue;
@@ -622,9 +622,9 @@ bool ProjectItem::closeOpenFiles()
if ( doc && !doc->fileClose() )
return false;
- m_tqchildren.remove( (ProjectItem*)0l );
- ProjectItemList::iterator end = m_tqchildren.end();
- for ( ProjectItemList::iterator it = m_tqchildren.begin(); it != end; ++it )
+ m_children.remove( (ProjectItem*)0l );
+ ProjectItemList::iterator end = m_children.end();
+ for ( ProjectItemList::iterator it = m_children.begin(); it != end; ++it )
{
if ( !(*it)->closeOpenFiles() )
return false;
@@ -668,9 +668,9 @@ void ProjectItem::addFile( const KURL & url )
if ( url.isEmpty() )
return;
- m_tqchildren.remove( (ProjectItem*)0l );
- ProjectItemList::iterator end = m_tqchildren.end();
- for ( ProjectItemList::iterator it = m_tqchildren.begin(); it != end; ++it )
+ m_children.remove( (ProjectItem*)0l );
+ ProjectItemList::iterator end = m_children.end();
+ for ( ProjectItemList::iterator it = m_children.begin(); it != end; ++it )
{
if ( (*it)->type() == FileType && (*it)->url() == url )
return;
@@ -788,7 +788,7 @@ bool ProjectInfo::open( const KURL & url )
TQFile file(target);
if ( !file.open( IO_ReadOnly ) )
{
- KMessageBox::sorry( 0l, i18n("Could not open %1 for reading").tqarg(target) );
+ KMessageBox::sorry( 0l, i18n("Could not open %1 for reading").arg(target) );
return false;
}
@@ -805,7 +805,7 @@ bool ProjectInfo::open( const KURL & url )
TQString errorMessage;
if ( !doc.setContent( xml, &errorMessage ) )
{
- KMessageBox::sorry( 0l, i18n("Couldn't parse xml:\n%1").tqarg(errorMessage) );
+ KMessageBox::sorry( 0l, i18n("Couldn't parse xml:\n%1").arg(errorMessage) );
return false;
}
@@ -845,7 +845,7 @@ bool ProjectInfo::save()
TQFile file( m_url.path() );
if ( file.open(IO_WriteOnly) == false )
{
- KMessageBox::sorry( NULL, i18n("Project could not be saved to \"%1\"").tqarg(m_url.path()), i18n("Saving Project") );
+ KMessageBox::sorry( NULL, i18n("Project could not be saved to \"%1\"").arg(m_url.path()), i18n("Saving Project") );
return false;
}
@@ -857,9 +857,9 @@ bool ProjectInfo::save()
// root.appendChild( LinkerOptions::toDomElement(doc) );
// root.appendChild( ProcessingOptions::toDomElement(doc) );
- m_tqchildren.remove( (ProjectItem*)0l );
- ProjectItemList::const_iterator end = m_tqchildren.end();
- for ( ProjectItemList::const_iterator it = m_tqchildren.begin(); it != end; ++it )
+ m_children.remove( (ProjectItem*)0l );
+ ProjectItemList::const_iterator end = m_children.end();
+ for ( ProjectItemList::const_iterator it = m_children.begin(); it != end; ++it )
root.appendChild( (*it)->toDomElement( doc, m_url ) );
TQTextStream stream(&file);
@@ -1130,7 +1130,7 @@ void ProjectManager::slotRemoveSelected()
if ( !currentItem )
return;
- int choice = KMessageBox::questionYesNo( this, i18n("Do you really want to remove \"%1\"?").tqarg( currentItem->text(0) ), i18n("Remove Project File?"), KGuiItem(i18n("Remove")), KGuiItem(i18n("Cancel")) );
+ int choice = KMessageBox::questionYesNo( this, i18n("Do you really want to remove \"%1\"?").arg( currentItem->text(0) ), i18n("Remove Project File?"), KGuiItem(i18n("Remove")), KGuiItem(i18n("Cancel")) );
if ( choice == KMessageBox::No )
return;
diff --git a/src/projectmanager.h b/src/projectmanager.h
index 33d239b..54f873f 100644
--- a/src/projectmanager.h
+++ b/src/projectmanager.h
@@ -160,11 +160,11 @@ class ProjectItem : public TQObject, public LinkerOptions, public ProcessingOpti
void setILVItem( ILVItem * ilvItem );
/**
* Adds the child to the list of tqchildren, and creates an ILVItem for it
* in the project tree view.
*/
void addChild( ProjectItem * child );
- ProjectItemList tqchildren() const { return m_tqchildren; }
+ ProjectItemList children() const { return m_children; }
void setName( const TQString & name );
TQString name() const { return m_name; }
@@ -180,12 +180,12 @@ class ProjectItem : public TQObject, public LinkerOptions, public ProcessingOpti
OutputType outputType() const;
/**
* Returns a list of output urls of the tqchildren and their recursively
* contained tqchildren (does not include the url for this project item).
* @param types An OR'ed list of ProjectItem::Type values for the
- * tqchildren.
+ * children.
* @param outputTypes An OR'ed list of ProjectItem::OutputType values
- * for the tqchildren.
+ * for the children.
*/
KURL::List childOutputURLs( unsigned types = AllTypes, unsigned outputTypes = AllOutputs ) const;
@@ -210,7 +210,7 @@ class ProjectItem : public TQObject, public LinkerOptions, public ProcessingOpti
virtual TQString microID() const;
/**
* Searches this item and the tqchildren for an item for the given url,
* return null if no such item could be found.
*/
ProjectItem * findItem( const KURL & url );
@@ -222,7 +222,7 @@ class ProjectItem : public TQObject, public LinkerOptions, public ProcessingOpti
KURL m_url;
TQString m_name;
- ProjectItemList m_tqchildren;
+ ProjectItemList m_children;
Type m_type;
KTechlab * p_ktechlab;
@@ -160,11 +160,11 @@ class ProjectItem : public TQObject, public LinkerOptions, public ProcessingOpti
void setILVItem( ILVItem * ilvItem );
/**
- * Adds the child to the list of tqchildren, and creates an ILVItem for it
+ * Adds the child to the list of children, and creates an ILVItem for it
* in the project tree view.
*/
@@ -180,12 +180,12 @@ class ProjectItem : public TQObject, public LinkerOptions, public ProcessingOpti
OutputType outputType() const;
/**
- * Returns a list of output urls of the tqchildren and their recursively
- * contained tqchildren (does not include the url for this project item).
+ * Returns a list of output urls of the children and their recursively
+ * contained children (does not include the url for this project item).
* @param types An OR'ed list of ProjectItem::Type values for the
@@ -210,7 +210,7 @@ class ProjectItem : public TQObject, public LinkerOptions, public ProcessingOpti
virtual TQString microID() const;
/**
- * Searches this item and the tqchildren for an item for the given url,
+ * Searches this item and the children for an item for the given url,
* return null if no such item could be found.
*/